OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversa",
    "(Duration %s)" : "(Durada %s)",
    "You attended a call with {user1}" : "Vau atendre una trucada amb {user1}",
    "_%n guest_::_%n guests_" : ["%n invitat","%n convidats"],
    "You attended a call with {user1} and {user2}" : "Vau atendre una trucada amb {user1} i {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Vau atendre una trucada amb {user1}, {user2} i {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Vau atendre una trucada amb {user1}, {user2}, {user3} i {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Vau atendre una trucada amb {user1}, {user2}, {user3}, {user4} i {user5}",
    "_%n other_::_%n others_" : ["altres %n","altres %n"],
    "{actor} invited you to {call}" : "{actor} us ha convidat a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Us han convidat a una <strong>conversa</strong> o heu rebut una <strong>trucada</strong>",
    "Other activities" : "Altres activitats",
    "Talk" : "Converses",
    "Guest" : "Convidat",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Benvingut a Nextcloud Parla!\n\nEn aquesta conversa se us informarà sobre les noves característiques a Parla.",
    "## New in Talk %s" : "## Novetat a Converses %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Ja es poden emprar Microsoft Edge i Safari per participar en trucades d'àudio i vídeo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Les converses individuals ara són persistents i ja no es poden convertir en converses de grup per accident. A més, quan un dels participants abandona la conversa, la conversa ja no se suprimeix automàticament. Només si els dos participants marxen, la conversa se suprimirà del servidor",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Podeu notificar ara a tots els participants al xat amb el comodí \"@all\"",
    "- With the \"arrow-up\" key you can repost your last message" : "- Usant la tecla de \"fletxa-amunt\" recupereu el vostre darrer missatge per tornar  a enviar-ho",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ara permet emprar comandaments, envieu \"/help\" com un missatge al xat per veure si el vostre administrador n'ha configurat algun",
    "- With projects you can create quick links between conversations, files and other items" : "- Amb els projectes podeu crear ràpidament enllaços entre converses, fitxers i altres elements a Nextcloud",
    "- You can now mention guests in the chat" : "- Ara ja podeu esmentar convidats al xat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Les converses ara poden tenir un vestíbul. Això permetrà als moderadors unir-se al xat i trucar ja per preparar la reunió, mentre que els usuaris i convidats han d'esperar",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Ara podeu respondre directament als missatges que donen als altres usuaris més context quant a el que el seu missatge es tracta",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- La recerca de converses i participants ara també filtrarà les converses existents, el que fa que sigui molt més fàcil trobar converses anteriors",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Ara podeu afegir grups d'usuaris personalitzats a les converses quan s'instal·li l'aplicació cercles",
    "- Check out the new grid and call view" : "- Reviseu la nova quadrícula i la visualització de trucades",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Ara pot pujar i arrossegar arxius directament des del seu dispositiu al xat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Els fitxers compartits s'obren ara directament dins de la vista de xat amb les aplicacions de visualització",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Ara podeu cercar xats i missatges a la cerca unificada de la barra superior",
    "- Spice up your messages with emojis from the emoji picker" : "- Salpebreu els vostres missatges amb emojis del selector d'emojis",
    "- You can now change your camera and microphone while being in a call" : "- Ara pots canviar la càmera i el micròfon mentre estàs en una trucada",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Contextualitza les teves converses amb una descripció i obre-la perquè els usuaris iniciats la puguin trobar i unir-se",
    "- See a read status and send failed messages again" : "- Veure un estat de lectura i tornar a enviar missatges fallits",
    "- Raise your hand in a call with the R key" : "- Alceu la mà en una trucada amb la tecla R",
    "- Join the same conversation and call from multiple devices" : "- Uneix-te a la mateixa conversa i truca des de diversos dispositius",
    "- Send voice messages, share your location or contact details" : "- Envia missatges de veu, comparteix la teva ubicació o detalls de contacte",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Afegiu grups a una conversa i els nous membres del grup s'afegiran automàticament com a participants",
    "- A preview of your audio and video is shown before joining a call" : "- Es mostra una vista prèvia del vostre àudio i vídeo abans d'unir-vos a una trucada",
    "- You can now blur your background in the newly designed call view" : "- Ara podeu desdibuixar el vostre fons a la vista de trucades recent dissenyada",
    "- Moderators can now assign general and individual permissions to participants" : "- Els moderadors ara poden assignar permisos generals i individuals als participants",
    "- You can now react to chat messages" : "- Ara podeu reaccionar als missatges de xat",
    "- In the sidebar you can now find an overview of the latest shared items" : "- A la barra lateral ara podeu trobar una visió general dels darrers elements compartits",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Utilitzeu una enquesta per recollir les opinions dels altres o establir una data",
    "- Configure an expiration time for chat messages" : "- Configureu un temps de caducitat per als missatges de xat",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Inicieu trucades sense avisar els altres en converses grans. Podeu enviar notificacions de trucades individuals un cop s'hagi iniciat la trucada.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Envia missatges de xat sense avisar als destinataris en cas que no sigui urgent",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Ara els emojis es poden completar automàticament escrivint un \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Enllaceu diversos elements mitjançant el nou selector intel·ligent escrivint un \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Els moderadors ara poden crear sales de treball (requereix el rerefons d'alt rendiment)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Ara es poden gravar les trucades (requereix el rerefons d'alt rendiment)",
    "- Conversations can now have an avatar or emoji as icon" : "- Les converses ara poden tenir un avatar o una emoticona com a icona",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Ara hi ha fons virtuals disponibles a més del fons borrós de les videotrucades",
    "- Reactions are now available during calls" : "- Les reaccions ara estan disponibles durant les trucades",
    "- Typing indicators show which users are currently typing a message" : "- Els indicadors d'escriptura mostren quins usuaris estan escrivint un missatge",
    "- Groups can now be mentioned in chats" : "- Els grups ara es poden esmentar als xats",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Els enregistraments de trucades es transcriuen automàticament si es registra una aplicació de proveïdor de transcripcions",
    "- Chat messages can be translated if a translation provider app is registered" : "- Els missatges de xat es poden traduir si una aplicació de proveïdor de traducció està registrada",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** ara es pot utilitzar als missatges de _xat_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Ara hi ha webhooks disponibles per implementar bots. Consulteu la documentació per obtenir més informació https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Establiu un recordatori en un missatge de xat per ser notificat més tard de nou",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Utilitza la conversa **Nota per a mi mateix** per prendre notes i compartir informació entre els teus dispositius",
    "- Captions allow to send a message with a file at the same time" : "- Els subtítols permeten enviar un missatge amb un fitxer al mateix temps",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- El vídeo de l'altaveu ara és visible mentre es comparteix la pantalla i les reaccions de trucada estan animades",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Ara els autors i moderadors registrats poden editar els missatges durant 6 hores",
    "- Unsent message drafts are now saved in your browser" : "- Els esborranys de missatges no enviats ara es guarden al vostre navegador",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- El xat de text ara es pot fer de manera federada amb altres servidors de Converses",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Els moderadors ara poden prohibir els comptes i els convidats per evitar que es tornin a unir a una conversa",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Les trucades properes d'esdeveniments del calendari enllaçats i els substituts fora de l'oficina ara es mostren a les converses",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Les trucades ara es poden fer de manera federada amb altres servidors Talk (requereix el rerefons d'alt rendiment)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Presentació del client d'escriptori Nextcloud Converses per a Windows, macOS i Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Resumiu els enregistraments de trucades i missatges no llegits als xats amb l'Assistent de Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Reunions millorades amb el reconeixement dels convidats convidats a través de la seva adreça de correu electrònic, importació de llistes de participants, esborranys per a enquestes i descàrrega de llistes de participants de trucades",
    "- Archive conversations to stay focused" : "- Arxiva les converses per mantenir la concentració",
    "- Schedule a meeting into your calendar from within a conversation" : "- Programeu una reunió al vostre calendari des d'una conversa",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Cerca missatges de la conversa actual directament a la barra lateral dreta",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Vegeu més converses a primera vista amb la nova llista compacta (activa a la configuració de Converses)",
    "_All %n participant_::_All %n participants_" : ["Tots el %n participant","Tots els %n participants"],
    "Talk updates ✅" : "Actualitzacions de Talk ✅",
    "Reaction deleted by author" : "Reacció suprimida per l'autor",
    "{actor} created the conversation" : "{actor} ha creat la conversa",
    "You created the conversation" : "Heu creat la conversa",
    "System created the conversation" : "El sistema ha creat la conversa",
    "An administrator created the conversation" : "Un administrador ha creat la conversa",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} ha canviat el nom de la conversa de  «%1$s» a «%2$s»",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Heu canviat el nom de la conversa de  \"%1$s\" a \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrador ha canviat el nom de la conversa de \"%1$s\" a \"%2$s\"",
    "{actor} set the description" : "{actor} defineix la descripció",
    "You set the description" : "Tu estableixes la descripció",
    "An administrator set the description" : "Un administrador ha establert la descripció",
    "{actor} removed the description" : "{actor} ha eliminat la descripció",
    "You removed the description" : "Has eliminat la descripció",
    "An administrator removed the description" : "Un administrador ha eliminat la descripció",
    "You started a silent call" : "Has iniciat una trucada silenciosa",
    "Outgoing silent call" : "Trucada silenciosa sortint",
    "{actor} started a silent call" : "{actor} ha iniciat una trucada silenciosa",
    "Incoming silent call" : "Trucada silenciosa entrant",
    "You started a call" : "Heu iniciat una trucada",
    "Outgoing call" : "Trucada sortint",
    "{actor} started a call" : "{actor} ha iniciat una trucada",
    "Incoming call" : "Trucada entrant",
    "{actor} joined the call" : "{actor} s'ha unit a la trucada",
    "You joined the call" : "Us heu unit a la trucada",
    "{actor} left the call" : "{actor} ha deixat la trucada",
    "You left the call" : "Heu deixat la trucada",
    "{actor} unlocked the conversation" : "{actor} ha desblocat la conversa",
    "You unlocked the conversation" : "Heu desblocat la conversa",
    "An administrator unlocked the conversation" : "Un administrador ha desbloquejat la conversa",
    "{actor} locked the conversation" : "{actor} ha blocat la conversa",
    "You locked the conversation" : "Heu blocat la conversa",
    "An administrator locked the conversation" : "Un administrador ha blocat la conversa",
    "{actor} limited the conversation to the current participants" : "{actor} ha limitat la conversa als participants actuals",
    "You limited the conversation to the current participants" : "Has limitat la conversa als participants actuals",
    "An administrator limited the conversation to the current participants" : "Un administrador ha limitat la conversa als participants actuals",
    "{actor} opened the conversation to registered users" : "{actor} ha obert la conversa als usuaris registrats",
    "You opened the conversation to registered users" : "Has obert la conversa als usuaris registrats",
    "An administrator opened the conversation to registered users" : "Un administrador va obrir la conversa als usuaris registrats",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} va obrir la conversa als usuaris registrats i als usuaris creats amb l'aplicació Convidats",
    "You opened the conversation to registered users and users created with the Guests app" : "Has obert la conversa als usuaris registrats i als usuaris creats amb l'aplicació Convidats",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Un administrador va obrir la conversa als usuaris registrats i als usuaris creats amb l'aplicació Convidats",
    "The conversation is now open to everyone" : "Ara la conversa està oberta a tothom",
    "{actor} opened the conversation to everyone" : "{actor} ha obert la conversa a tothom",
    "You opened the conversation to everyone" : "Heu obert la conversa a tothom",
    "{actor} restricted the conversation to moderators" : "{actor} ha restringit la conversa als moderadors",
    "You restricted the conversation to moderators" : "Heu restringit la conversa als moderadors",
    "{actor} started breakout rooms" : "{actor} ha començat les sales de grup",
    "You started breakout rooms" : "Has començat a les sales de grup",
    "{actor} stopped breakout rooms" : "{actor} han aturat les sales de grup",
    "You stopped breakout rooms" : "Has aturat les sales de descans",
    "{actor} allowed guests" : "{actor} ha permès convidats",
    "You allowed guests" : "Heu permès convidats",
    "An administrator allowed guests" : "Un administrador ha permès convidats",
    "{actor} disallowed guests" : "{actor} ha deixat de permetre convidats",
    "You disallowed guests" : "Heu deixat de permetre convidats",
    "An administrator disallowed guests" : "Un administrador no permet convidats",
    "{actor} set a password" : "{actor} a establert una contrasenya",
    "You set a password" : "Heu establert una contrasenya",
    "An administrator set a password" : "Un administrador ha definit una contrasenya",
    "{actor} removed the password" : "{actor} ha tret la contrasenya",
    "You removed the password" : "Heu tret la contrasenya",
    "An administrator removed the password" : "Un administrador ha suprimit la contrasenya",
    "{actor} added {user}" : "{actor} ha afegit a {user}",
    "You joined the conversation" : "Us heu sumat a la conversa",
    "{actor} joined the conversation" : "{actor} s'ha sumat a la conversa",
    "You added {user}" : "Heu afegit a {user}",
    "{actor} added you" : "{actor} us ha afegit",
    "An administrator added you" : "Un administrador us ha afegit",
    "An administrator added {user}" : "Un administrador ha afegit a {user}",
    "You left the conversation" : "Heu deixat la conversa",
    "{actor} left the conversation" : "{actor} ha deixat la conversa",
    "{actor} removed {user}" : "{actor} ha fet fora a {user}",
    "You removed {user}" : "Heu fet fora a {user}",
    "{actor} removed you" : "{actor} us ha fet fora",
    "An administrator removed you" : "Un administrador us ha suprimit",
    "An administrator removed {user}" : "Un administrador ha suprimit a {user}",
    "{actor} invited {federated_user}" : "{actor} ha convidat {federated_user}",
    "You invited {federated_user}" : "Has convidat {federated_user}",
    "You accepted the invitation" : "Heu acceptat aquesta invitació",
    "{actor} invited you" : "{actor} t'ha convidat",
    "An administrator invited you" : "Un administrador t'ha convidat",
    "An administrator invited {federated_user}" : "Un administrador ha convidat {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} ha acceptat la invitació",
    "{actor} removed {federated_user}" : "{actor} ha eliminat {federated_user}",
    "You removed {federated_user}" : "Has eliminat {federated_user}",
    "You declined the invitation" : "Heu rebutjat aquesta invitació",
    "An administrator removed {federated_user}" : "Un administrador ha eliminat {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} ha rebutjat la invitació",
    "{actor} added group {group}" : "{actor} ha afegit el grup {group}",
    "You added group {group}" : "Heu afegit el grup {group}",
    "An administrator added group {group}" : "Un administrador ha afegit el grup {group}",
    "{actor} removed group {group}" : "{actor} ha suprimit el grup {group}",
    "You removed group {group}" : "Heu suprimit el grup {group}",
    "An administrator removed group {group}" : "Un administrador ha eliminat el grup {group}",
    "{actor} added team {circle}" : "{actor} ha afegit l'equip {circle}",
    "You added team {circle}" : "Heu afegit l'equip {circle}",
    "An administrator added team {circle}" : "Un administrador ha afegit l'equip {circle}",
    "{actor} removed team {circle}" : "{actor} equip eliminat {circle}",
    "You removed team {circle}" : "Has eliminat l'equip {circle}",
    "An administrator removed team {circle}" : "Un administrador ha eliminat l'equip {circle}",
    "{actor} added {phone}" : "{actor} ha afegit {phone}",
    "You added {phone}" : "Heu afegit {phone}",
    "An administrator added {phone}" : "Un administrador ha afegit {phone}",
    "{actor} removed {phone}" : "{actor} ha eliminat {phone}",
    "You removed {phone}" : "Has eliminat {phone}",
    "An administrator removed {phone}" : "Un administrador ha eliminat {phone}",
    "{actor} promoted {user} to moderator" : "{actor} ha promogut {user} a moderador",
    "You promoted {user} to moderator" : "Heu promogut {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} us ha promogut a moderador",
    "An administrator promoted you to moderator" : "Un administrador us ha promogut com a moderador",
    "An administrator promoted {user} to moderator" : "Un administrador ha promogut a {user} a moderador",
    "{actor} demoted {user} from moderator" : "{actor} li ha tret el rol de moderador a {user}",
    "You demoted {user} from moderator" : "Li heu tret el rol de moderador a {user}",
    "{actor} demoted you from moderator" : "{actor} us ha tret el rol de moderador",
    "An administrator demoted you from moderator" : "Un administrador us ha degradat de moderador",
    "An administrator demoted {user} from moderator" : "Un administrador va degradar a {user} de moderador",
    "{actor} shared a file which is no longer available" : "{actor} va compartir un fitxer que ja no està disponible",
    "You shared a file which is no longer available" : "Vau compartir un fitxer que ja no està disponible",
    "File shares are currently not supported in federated conversations" : "Actualment no s'admeten els recursos compartits de fitxers a les converses federades",
    "The shared location is malformed" : "La ubicació compartida té un format incorrecte",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ha configurat Matterbridge per sincronitzar aquesta conversa amb altres xats",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Has configurat Matterbridge per sincronitzar aquesta conversa amb altres xats",
    "{actor} updated the Matterbridge configuration" : "{actor} ha actualitzat la configuració de Matterbridge",
    "You updated the Matterbridge configuration" : "Heu actualitzat la configuració de Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} ha eliminat la configuració de Matterbridge",
    "You removed the Matterbridge configuration" : "Heu eliminat la configuració de Matterbridge",
    "{actor} started Matterbridge" : "{actor} va iniciar Matterbridge",
    "You started Matterbridge" : "Vas començar Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} va aturar Matterbridge",
    "You stopped Matterbridge" : "Vas aturar Matterbridge",
    "{actor} deleted a message" : "{actor} ha suprimit un missatge",
    "You deleted a message" : "Has suprimit un missatge",
    "{actor} edited a message" : "{actor} ha editat un missatge",
    "You edited a message" : "Has editat un missatge",
    "{actor} deleted a reaction" : "{actor} ha suprimit una reacció",
    "You deleted a reaction" : "Has suprimit una reacció",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Heu establert la caducitat del missatge en %n setmana","Heu establert la caducitat del missatge en %n setmanes"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Heu establert la caducitat del missatge en %n dia","Heu establert la caducitat del missatge en %n dies"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Heu establert la caducitat del missatge en %n hores","Heu establert la caducitat del missatge en %n hores"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Heu establert la caducitat del missatge en %n minut","Heu establert la caducitat del missatge en %n minuts"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} estableix la caducitat del missatge en %n setmana","{actor} estableix la caducitat del missatge en %n setmanes"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} defineix la caducitat del missatge en %n dia","{actor} estableix la caducitat del missatge en %n dies"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} defineix la caducitat del missatge en %n hora","{actor} defineix la caducitat del missatge en %n hores"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} defineix la caducitat del missatge en %n minut","{actor} defineix la caducitat del missatge en %n minuts"],
    "{actor} disabled message expiration" : "{actor} ha desactivat la caducitat del missatge",
    "You disabled message expiration" : "Heu desactivat la caducitat del missatge",
    "{actor} cleared the history of the conversation" : "{actor} ha esborrat l'historial de la conversa",
    "You cleared the history of the conversation" : "Has esborrat l'historial de la conversa",
    "{actor} set the conversation picture" : "{actor} defineix la imatge de la conversa",
    "You set the conversation picture" : "Tu has configurat la imatge de la conversa",
    "{actor} removed the conversation picture" : "{actor} ha eliminat la imatge de la conversa",
    "You removed the conversation picture" : "Has eliminat la imatge de la conversa",
    "{actor} ended the poll {poll}" : "{actor} ha acabat l'enquesta {poll}",
    "You ended the poll {poll}" : "Has acabat l'enquesta {poll}",
    "{actor} started the video recording" : "{actor} va iniciar la gravació del vídeo",
    "You started the video recording" : "Has començat la gravació del vídeo",
    "{actor} stopped the video recording" : "{actor} ha aturat la gravació del vídeo",
    "You stopped the video recording" : "Has aturat la gravació del vídeo",
    "{actor} started the audio recording" : "{actor} va iniciar la gravació d'àudio",
    "You started the audio recording" : "Has començat la gravació d'àudio",
    "{actor} stopped the audio recording" : "{actor} ha aturat la gravació d'àudio",
    "You stopped the audio recording" : "Has aturat la gravació d'àudio",
    "The recording failed" : "La gravació ha fallat",
    "Someone voted on the poll {poll}" : "Algú ha votat a l'enquesta {poll}",
    "Message deleted by author" : "Missatge suprimit per l'autor",
    "Message deleted by {actor}" : "Missatge suprimit per {actor}",
    "Message deleted by you" : "Missatge suprimit per tu",
    "Deleted user" : "Usuari suprimit",
    "Unknown number" : "Número desconegut",
    "Administration" : "Administració",
    "System" : "Sistema",
    "%s (guest)" : "%s (convidat)",
    "Missed call" : "Trucada perduda",
    "Call ended (Duration {duration})" : "Trucada finalitzada (durada {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "La trucada s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} ha finalitzat la trucada (durada {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["La trucada amb %n convidat s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})","La trucada amb %n convidats s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (durada {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Trucada amb %n convidat finalitzada (Durada {duration})","Trucada amb %n convidats finalitzada (durada {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ha finalitzat la trucada amb %n convidat (Durada {duration})","{actor} ha finalitzat la trucada amb %n convidats (Durada {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "La trucada amb {user1} s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})",
    "Call with {user1} ended (Duration {duration})" : "Trucada amb {user1} finalitzada (Durada {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ha finalitzat la trucada amb {user1} (Durada {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "La trucada amb {user1} i {user2} s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Trucada amb {user1} i {user2} finalitzada (durada {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ha finalitzat la trucada amb {user1} i {user2} (Durada {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "La trucada amb {user1}, {user2} i {user3} s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Trucada amb {user1}, {user2} i {user3} finalitzada (durada {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ha finalitzat la trucada amb {user1}, {user2} i {user3} (Durada {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "La trucada amb {user1}, {user2}, {user3} i {user4} s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Trucada amb {user1}, {user2}, {user3} i {user4} finalitzada (durada {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ha finalitzat la trucada amb {user1}, {user2}, {user3} i {user4} (Durada {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "La trucada amb {user1}, {user2}, {user3}, {user4} i {user5} s'ha finalitzat, ja que s'ha arribat a la durada màxima de la trucada (Durada {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Trucada amb {user1}, {user2}, {user3}, {user4} i {user5} finalitzada (durada {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} va finalitzar la trucada amb {user1}, {user2}, {user3}, {user4} i {user5} (Durada {duration})",
    "Message of {user} in {conversation}" : "Missatge de {user} a {conversation}",
    "Message of {user}" : "Missatge de {user}",
    "Message of a deleted user in {conversation}" : "Missatge d'un usuari suprimit a {conversation}",
    "Talk conversations" : "Converses",
    "Call %s" : "Truca a %s",
    "An error occurred. Please contact your administrator." : "Hi ha hagut un error. Poseu-vos en contacte amb el vostre administrador.",
    "File not found" : "No s'ha trobat el fitxer",
    "File is not shared, or shared but not with the user" : "El fitxer no és compartit, o ho és però no amb l'usuari",
    "No account available to delete." : "No hi ha cap compte disponible per suprimir.",
    "Poll" : "Enquesta",
    "Password needs to be set" : "S'ha d'establir la contrasenya",
    "Uploading the file failed" : "No s'ha pogut carregar el fitxer",
    "No image file provided" : "No s'ha proporcionat cap imatge o fitxer",
    "File is too big" : "El fitxer és massa gran",
    "Invalid file provided" : "El fitxer proporcionat no és vàlid",
    "Invalid image" : "La imatge no és vàlida",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Talk mentions" : "Mencions de Talk",
    "More conversations" : "Més converses",
    "Say hi to your friends and colleagues!" : "Saludeu els vostres amics i col·legues!",
    "No unread mentions" : "No hi ha mencions no llegides",
    "Call in progress" : "S'està fent una trucada",
    "You were mentioned" : "Se li va mencionar",
    "Write to conversation" : "Escriu a la conversa",
    "Writes event information into a conversation of your choice" : "Escriu informació de l'esdeveniment en una conversa de la vostra elecció",
    "Missing email field in header line" : "Falta el camp de correu electrònic a la línia de capçalera",
    "Following lines are invalid: %s" : "Les línies següents no són vàlides: %s",
    "Conversation invitation" : "Invitació a conversar",
    "Description" : "Descripció",
    "You can also dial-in via phone with the following details" : "També podeu marcar per telèfon amb els detalls següents",
    "Dial-in information" : "Informació de marcatge",
    "Meeting ID" : "ID de la reunió",
    "Your PIN" : "El teu PIN",
    "Meeting" : "Reunió",
    "Password request: %s" : "Petició de contrasenya: %s",
    "Private conversation" : "Conversa privada",
    "Deleted user (%s)" : "Usuari (%s) suprimit",
    "Failed to upload call recording" : "No s'ha pogut pujar l'enregistrament de la trucada",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "El servidor de gravació no ha pogut pujar l'enregistrament de la trucada {call}. Si us plau, poseu-vos en contacte amb l'administració.",
    "Share to chat" : "Comparteix per xatejar",
    "Dismiss notification" : "Descarta la notificació",
    "Call recording now available" : "Ja està disponible l'enregistrament de trucades",
    "The recording for the call in {call} was uploaded to {file}." : "La gravació de la trucada a {call} s'ha penjat a {file}.",
    "Transcript now available" : "Transcripció ja disponible",
    "The transcript for the call in {call} was uploaded to {file}." : "La transcripció de la trucada a {call} s'ha penjat a {file}.",
    "Failed to transcript call recording" : "No s'ha pogut transcriure l'enregistrament de la trucada",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "El servidor no ha pogut transcriure l'enregistrament a {file} per a la trucada a {call}. Si us plau, poseu-vos en contacte amb l'administració.",
    "Call summary now available" : "Ja està disponible el resum de la trucada",
    "The summary for the call in {call} was uploaded to {file}." : "El resum de la trucada a {call} s'ha penjat a {file}.",
    "Failed to summarize call recording" : "No s'ha pogut resumir l'enregistrament de la trucada",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "El servidor no ha pogut resumir l'enregistrament a {file} per a la trucada a {call}. Si us plau, poseu-vos en contacte amb l'administració.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} t'ha convidat a unir-te a {roomName} a {remoteServer}",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "{user1} invited you to a federated conversation" : "{user1} t'ha convidat a una conversa federada",
    "New message" : "Escriu un missatge",
    "Reminder" : "Recordatori",
    "Notification" : "Notificació",
    "Reminder: You in {call}" : "Recordatori: tu a {call}",
    "Reminder: {user} in {call}" : "Recordatori: {user} a {call}",
    "Reminder: Deleted user in {call}" : "Recordatori: usuari suprimit a {call}",
    "Reminder: {guest} (guest) in {call}" : "Recordatori: {guest} (convidat) a {call}",
    "Reminder: Guest in {call}" : "Recordatori: convidat a {call}",
    "{user} reacted with {reaction}" : "{user} ha reaccionat amb {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} ha reaccionat amb {reaction} a {call}",
    "Deleted user reacted with {reaction} in {call}" : "L'usuari suprimit ha reaccionat amb {reaction} a {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (convidat) ha reaccionat amb {reaction} a {call}",
    "Guest reacted with {reaction} in {call}" : "El convidat ha reaccionat amb {reaction} a {call}",
    "{user} in {call}" : "{user} a {call}",
    "Deleted user in {call}" : "Usuari suprimit a {call}",
    "{guest} (guest) in {call}" : "{guest} (convidat) a {call}",
    "Guest in {call}" : "Convidat a {call}",
    "{user} sent you a private message" : "{user} us ha enviat un missatge privat",
    "{user} sent a message in conversation {call}" : "{user} ha enviat un missatge a la conversa {call}",
    "A deleted user sent a message in conversation {call}" : "Un usuari que va ser suprimit ha enviat un missatge a la conversa {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) ha enviat un missatge a la conversa {call}",
    "A guest sent a message in conversation {call}" : "Un convidat ha enviat un missatge a la conversa {call}",
    "{user} replied to your private message" : "{user} ha respost al vostre missatge privat",
    "{user} replied to your message in conversation {call}" : "{user} ha respost al vostre missatge a la conversa {call}",
    "A deleted user replied to your message in conversation {call}" : "Un usuari que va ser suprimit ha respost al vostre missatge a la conversa {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (convidat) ha respost al vostre missatge a la conversa {call}",
    "A guest replied to your message in conversation {call}" : "Un usuari convidat ha respost al vostre missatge a la conversa {call}",
    "Reminder: You in private conversation {call}" : "Recordatori: estàs en una conversa privada {call}",
    "Reminder: A deleted user in private conversation {call}" : "Recordatori: un usuari suprimit en una conversa privada {call}",
    "Reminder: {user} in private conversation" : "Recordatori: {user} en conversa privada",
    "Reminder: You in conversation {call}" : "Recordatori: tu estàs a la conversa {call}",
    "Reminder: {user} in conversation {call}" : "Recordatori: {user} a la conversa {call}",
    "Reminder: A deleted user in conversation {call}" : "Recordatori: un usuari suprimit a la conversa {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Recordatori: {guest} (convidat) a la conversa {call}",
    "Reminder: A guest in conversation {call}" : "Recordatori: un convidat a la conversa {call}",
    "{user} reacted with {reaction} to your private message" : "{user} ha reaccionat amb {reaction} al teu missatge privat",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} ha reaccionat amb {reaction} al teu missatge a la conversa {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un usuari suprimit ha reaccionat amb {reaction} al teu missatge a la conversa {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (convidat) ha reaccionat amb {reaction} al teu missatge a la conversa {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un convidat ha reaccionat amb {reaction} al teu missatge a la conversa {call}",
    "{user} mentioned you in a private conversation" : "{user} us ha mencionat en una conversa privada",
    "{user} mentioned group {group} in conversation {call}" : "{user} va mencionar el grup {group} a la conversa {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} va mencionar l'equip {team} a la conversa {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} ha mencionat tothom a la conversa {call}",
    "{user} mentioned you in conversation {call}" : "{user} us ha mencionat a la conversa {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Un usuari suprimit ha mencionat el grup {group} a la conversa {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Un usuari suprimit ha mencionat l'equip {team} a la conversa {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Un usuari suprimit ha mencionat tothom a la conversa {call}",
    "A deleted user mentioned you in conversation {call}" : "Un usuari suprimit us ha mencionat a la conversa {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (convidat) ha mencionat el grup {group} a la conversa {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (convidat) va mencionar l'equip {team} a la conversa {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (convidat) ha mencionat tothom a la conversa {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) us ha mencionat a la conversa {call}",
    "A guest mentioned group {group} in conversation {call}" : "Un convidat ha mencionat el grup {group} a la conversa {call}",
    "A guest mentioned team {team} in conversation {call}" : "Un convidat va mencionar l'equip {team} a la conversa {call}",
    "A guest mentioned everyone in conversation {call}" : "Un convidat ha mencionat tothom a la conversa {call}",
    "A guest mentioned you in conversation {call}" : "Un convidat us ha mencionat a la conversa {call}",
    "View message" : "Visualitza el missatge",
    "Dismiss reminder" : "Descarta el recordatori",
    "View chat" : "Mostra el xat",
    "{user} invited you to a group conversation: {call}" : "{user} us ha convidat a una conversa grupal:  {call}",
    "Join call" : "Uneix-te a la trucada",
    "Answer call" : "Respon la trucada",
    "{user} would like to talk with you" : "{user} vol parlar amb tu",
    "Call back" : "Torna la trucada",
    "You missed a call from {user}" : "Teniu una trucada perduda de {user}",
    "A group call has started in {call}" : "S'ha iniciat una trucada grupal a {call}",
    "You missed a group call in {call}" : "Teniu una trucada de grup perduda a {call}",
    "{email} is requesting the password to access {file}" : "{email} està demanant la contrasenya per accedir a {file}",
    "{email} tried to request the password to access {file}" : "{email} ha intentat sol·licitar la contrasenya per accedir a {file}",
    "Someone is requesting the password to access {file}" : "Algú està demanant la contrasenya per accedir a {file}",
    "Someone tried to request the password to access {file}" : "Algú ha intentat sol·licitar la contrasenya per accedir a {file}",
    "Open settings" : "Obre els paràmetres",
    "Hosted signaling server added" : "S'ha afegit un servidor de senyalització allotjat",
    "The hosted signaling server is now configured and will be used." : "El servidor de senyalització allotjat ja està configurat i s'utilitzarà.",
    "Hosted signaling server removed" : "S'ha eliminat el servidor de senyalització allotjat",
    "The hosted signaling server was removed and will not be used anymore." : "El servidor de senyalització allotjat s'ha suprimit i ja no s'utilitzarà.",
    "Hosted signaling server changed" : "S'ha canviat el servidor de senyalització allotjat",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "El compte del servidor de senyalització allotjat ha canviat l'estat de \"{oldstatus}\" a \"{newstatus}\".",
    "pending" : "pendent",
    "active" : "actiu",
    "expired" : "caducat",
    "blocked" : "bloquejat",
    "error" : "error",
    "The certificate of {host} expires in {days} days" : "El certificat de {host} caduca d'aquí a {days} dies",
    "The certificate of {host} expired" : "El certificat de {host} ha caducat",
    "Contact via Talk" : "Contacta mitjançant Talk",
    "Open Talk" : "Obre Talk",
    "Default" : "Per defecte",
    "Presentation" : "Presentació",
    "Conversations" : "Converses",
    "Messages in current conversation" : "Missatges de la conversa actual",
    "{user}" : "{user}",
    "Messages" : "Missatges",
    "{user} in {conversation}" : "{user} a {conversation}",
    "Messages in other conversations" : "Missatges en altres converses",
    "One-to-one rooms always need to show the other users avatar" : "Les sales d'un a un sempre han de mostrar l'avatar dels altres usuaris",
    "Invalid emoji character" : "Caràcter emoticona no vàlid",
    "Invalid background color" : "Color de fons no vàlid",
    "Avatar image is not square" : "La imatge de l'avatar no és quadrada",
    "Room {number}" : "Sala {number}",
    "Favorites" : "Preferits",
    "Other" : "Altres",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "No s'ha pogut sol·licitar la prova perquè el servidor de prova no és accessible. Torneu-ho a provar més tard.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Hi ha un problema amb l'autenticació d'aquesta instància. Potser no es pot arribar des de l'exterior per verificar l’URL.",
    "Something unexpected happened." : "Ha passat una cosa inesperada.",
    "The URL is invalid." : "L'URL és invàlid.",
    "An HTTPS URL is required." : "Cal un URL HTTPS.",
    "The email address is invalid." : "L'adreça de correu electrònic no és vàlida.",
    "The language is invalid." : "La llengua no és vàlida.",
    "The country is invalid." : "El país no és vàlid.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Hi ha un problema amb la sol·licitud de la prova. Si us plau, comproveu els registres per obtenir més informació.",
    "Too many requests are send from your servers address. Please try again later." : "S'envien massa sol·licituds des d'adreces dels seus servidors. Torneu-ho a provar més tard.",
    "There is already a trial registered for this Nextcloud instance." : "Ja hi ha una prova registrada per a aquesta instància Nextcloud.",
    "Something unexpected happened. Please try again later." : "Ha passat una cosa inesperada. Torneu-ho a provar més tard.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "No s'ha pogut sol·licitar la prova perquè el servidor de prova s'ha comportat malament. Torneu-ho a provar més tard.",
    "Trial requested but failed to get account information. Please check back later." : "S'ha sol·licitat la prova, però no s'ha pogut obtenir informació del compte. Torneu a comprovar-ho més tard.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Hi ha un problema amb l'autenticació d'aquesta sol·licitud. Potser no es pot arribar des de l'exterior per verificar l'URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "No s'ha pogut obtenir la informació del compte perquè el servidor de prova s'ha comportat malament. Torneu a comprovar-ho més tard.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Hi ha un problema amb l'obtenció de la informació del compte. Si us plau, comproveu els registres per obtenir més informació.",
    "There is no such account registered." : "No hi ha aquest compte registrat.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "No s'ha pogut obtenir la informació del compte perquè el servidor de prova no és accessible. Torneu a comprovar-ho més tard.",
    "Deleting the hosted signaling server account failed. Please check back later." : "No s'ha pogut suprimir el compte del servidor de senyalització allotjat. Torneu a comprovar-ho més tard.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "No s'ha pogut suprimir el compte perquè el servidor de prova s'ha comportat malament. Torneu a comprovar-ho més tard.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Hi ha un problema en suprimir el compte. Si us plau, comproveu els registres per obtenir més informació.",
    "Too many requests are sent from your servers address. Please try again later." : "S'envien massa sol·licituds des de l'adreça del vostre servidor. Siusplau, torneu-ho a provar més tard.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "No s'ha pogut suprimir el compte perquè el servidor de prova no és accessible. Torneu a comprovar-ho més tard.",
    "Note to self" : "Nota per a un mateix",
    "A place for your private notes, thoughts and ideas" : "Un lloc per a les teves notes, pensaments i idees privades",
    "Transcript is AI generated and may contain mistakes" : "La transcripció es genera amb intel·ligència artificial i pot contenir errors",
    "Summary is AI generated and may contain mistakes" : "El resum es genera amb IA i pot contenir errors",
    "Let's get started!" : "Comencem!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Converses** és una plataforma de comunicació segura i autoallotjada que s'integra perfectament amb l'ecosistema Nextcloud.\n\n#### Característiques clau de Nextcloud Converses:\n\n* Xateja i missatgeria en xats privats i de grup\n* Trucades de veu i videotrucades\n* Compartició de fitxers i integració amb altres aplicacions de Nextcloud\n* Configuració de conversa personalitzable, moderació i controls de privadesa\n* Web, escriptori i mòbil (iOS i Android)\n* Comunicació privada i segura\n\n Més informació a la [documentació de l'usuari](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Benvingut a Nextcloud Converses\n\nNextcloud Converses és una aplicació de missatgeria privada i potent que s'integra amb Nextcloud. Xateja en converses privades o en grup, col·labora mitjançant trucades de veu i videotrucades, organitza seminaris web i esdeveniments, personalitza les teves converses i molt més.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formateu textos per crear missatges rics\n\nA Nextcloud Converses, podeu utilitzar la sintaxi de Markdown per formatar els vostres missatges. Per exemple, apliqueu el format **negreta** o *cursiva*, o bé \"ressalteu textos com a codi\". Fins i tot podeu crear taules i afegir encapçalaments al vostre text.\n\nNecessites corregir una errada ortogràfica o canviar el format? Editeu el vostre missatge fent clic a \"Edita missatge\" al menú de missatges.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Afegeix fitxers adjunts i enllaços\n\nAdjunteu fitxers del vostre Nextcloud Hub mitjançant el botó \"+\". Comparteix elements de Files i de diverses aplicacions de Nextcloud. Algunes aplicacions fins i tot admeten ginys interactius, per exemple, l'aplicació Text.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Pots respondre missatges, reenviar-los a altres xats i persones, o copiar el contingut del missatge.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Fes més amb Smart Picker\n\nSimplement escriviu \"/\" o aneu al menú \"+\" per obrir el selector intel·ligent on podeu adjuntar diversos continguts als vostres missatges. Podeu configurar el selector intel·ligent per poder afegir elements d'aplicacions Nextcloud, GIF, ubicacions de mapes, contingut generat per IA i molt més.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Gestiona la configuració de la conversa\n\nAl menú de converses, podeu accedir a diverses configuracions per gestionar les vostres converses, com ara:\n* Edita la informació de la conversa\n* Gestiona les notificacions\n* Aplicar nombroses regles de moderació\n* Configura l'accés i la seguretat\n* Habilita els bots\n* i més!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirats Àrabs Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua i Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albània",
    "Armenia" : "Armènia",
    "Angola" : "Angola",
    "Antarctica" : "Antàrtida",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Nord-americana",
    "Austria" : "Àustria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illes Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia i Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgària",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermudes",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Bolívia, estat plurinacional de",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius i Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahames",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorússia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illes Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, República Democràtica del",
    "Central African Republic" : "República Centreafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suïssa",
    "Côte d'Ivoire" : "Costa d'Ivori",
    "Cook Islands" : "Illes Cook",
    "Chile" : "Xile",
    "Cameroon" : "Camerun",
    "China" : "Xina",
    "Colombia" : "Colòmbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Christmas",
    "Cyprus" : "Xipre",
    "Czechia" : "Txèquia",
    "Germany" : "Alemanya",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algèria",
    "Ecuador" : "Equador",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "Western Sahara" : "Sàhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "Espanya",
    "Ethiopia" : "Etiòpia",
    "Finland" : "Finlàndia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Illes Malvines (Falkland)",
    "Micronesia, Federated States of" : "Micronèsia, Estats Federats de la",
    "Faroe Islands" : "Illes Fèroe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Regne Unit de Gran Bretanya i Irlanda del nord",
    "Grenada" : "Grenada",
    "Georgia" : "Geòrgia",
    "French Guiana" : "Guaiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlàndia",
    "Gambia" : "Gàmbia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Equatorial",
    "Greece" : "Grècia",
    "South Georgia and the South Sandwich Islands" : "Illes Geòrgia del Sud i Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illes Heard i McDonald",
    "Honduras" : "Hondures",
    "Croatia" : "Croàcia",
    "Haiti" : "Haití",
    "Hungary" : "Hongria",
    "Indonesia" : "Indonèsia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territori Britànic de l'Oceà Índic",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Itàlia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordània",
    "Japan" : "Japó",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirguizistan",
    "Cambodia" : "Cambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts i Nevis",
    "Korea, Democratic People's Republic of" : "Corea, República Popular Democràtica de",
    "Korea, Republic of" : "Corea, República de",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Illes Caiman",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "República Democràtica Popular Lao",
    "Lebanon" : "Líban",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letònia",
    "Libya" : "Líbia",
    "Morocco" : "Marroc",
    "Monaco" : "Mònaco",
    "Moldova, Republic of" : "Moldàvia, República de",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Sant Martí (part francesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illes Marshall",
    "North Macedonia" : "Macedònia del Nord",
    "Mali" : "Mali",
    "Myanmar" : "Birmània",
    "Mongolia" : "Mongòlia",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Illes Marianes del Nord",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Illa de Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mèxic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledònia",
    "Niger" : "Níger",
    "Norfolk Island" : "Illa Norfolk",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Països Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Perú",
    "French Polynesia" : "Polinèsia Francesa",
    "Papua New Guinea" : "Papua Nova Guinea",
    "Philippines" : "Filipines",
    "Pakistan" : "Pakistan",
    "Poland" : "Polònia",
    "Saint Pierre and Miquelon" : "Sant Pere i Miquelon",
    "Pitcairn" : "Illes Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina, Estat de",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "Reunió",
    "Romania" : "Romania",
    "Serbia" : "Sèrbia",
    "Russian Federation" : "Rússia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Aràbia Saudita",
    "Solomon Islands" : "Illes Salomó",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascensió i Tristan da Cunha",
    "Slovenia" : "Eslovènia",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Eslovàquia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somàlia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "São Tomé i Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (part holandesa)",
    "Syrian Arab Republic" : "República Àrab Siriana",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Illes Turks i Caicos",
    "Chad" : "Txad",
    "French Southern Territories" : "Territoris Francesos del Sud",
    "Togo" : "Togo",
    "Thailand" : "Tailàndia",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzània, República Unida de",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Illes Perifèriques Menors dels EUA",
    "United States of America" : "Estats Units d'Amèrica",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Santa Seu",
    "Saint Vincent and the Grenadines" : "Saint Vincent i les Grenadines",
    "Venezuela, Bolivarian Republic of" : "Veneçuela, República Bolivariana de",
    "Virgin Islands, British" : "Illes Verges britàniques",
    "Virgin Islands, U.S." : "Illes Verges, EUA.",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sud-àfrica",
    "Zambia" : "Zàmbia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Desactiva el desenfocament de fons",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "No s'ha pogut comprovar el suport de càrrega de WASM. Comproveu manualment si el vostre servidor web ofereix fitxers `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "El vostre servidor web no està configurat correctament per lliurar fitxers `.wasm`. Això sol ser un problema amb la configuració de Nginx. Per al desenfocament de fons, necessita un ajust per oferir també fitxers `.wasm`. Compareu la vostra configuració de Nginx amb la configuració recomanada a la nostra documentació.",
    "Talk configuration values" : "Valors de configuració de Converses",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Forçar la durada d'una trucada només s'admet amb el cron del sistema. Si us plau, activeu el cron del sistema o elimineu la configuració `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Els valors petits de \"max_call_duration\" (actualment establerts en %d) no es poden aplicar a causa de limitacions tècniques. El treball en segon pla només s'executa cada 5 minuts, així que utilitzeu-lo sota el vostre risc.",
    "Federation" : "Federació",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "És molt recomanable configurar \"memcache.locking\" quan la Federació de Converses estigui habilitada.",
    "High-performance backend" : "Rerefons d'alt rendiment",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "No s'ha configurat el rerefons d'alt rendiment: l'execució de Nextcloud Converses sense el rerefons d'alt rendiment només s'escala per a trucades molt petites (màx. 2-3 participants). Configureu el rerefons d'alt rendiment per garantir que les trucades amb diversos participants funcionin perfectament.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "L'execució del mode de rerefons d'alt rendiment \"conversation_cluster\" està obsolet i ja no s'admetrà a la propera versió. El rerefons d'alt rendiment admet actualment un clustering real que s'hauria d'utilitzar.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "La definició de diversos rerefons d'alt rendiment està obsoleta i ja no s'admetrà a la propera versió. En lloc d'això, s'ha de configurar un equilibrador de càrrega juntament amb servidors de senyalització agrupats i configurar-lo a la configuració de Converses.",
    "High-performance backend not configured correctly" : "El rerefons d'alt rendiment no s'ha configurat correctament",
    "Error: Cannot connect to server" : "Error: no es pot connectar al servidor",
    "Error: Server did not respond with proper JSON" : "Error: el servidor no ha respost amb el JSON adequat",
    "Error: Certificate expired" : "Error: el certificat ha caducat",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Error: els temps del sistema del servidor Nextcloud i el servidor de fons d'alt rendiment no estan sincronitzats. Assegureu-vos que tots dos servidors estiguin connectats a un servidor d'hora o sincronitzeu manualment la seva hora.",
    "Could not get version" : "No s'ha pogut obtenir la versió",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Error: versió en execució: {version}; El servidor s'ha d'actualitzar per ser compatible amb aquesta versió de Talk",
    "Error: Server responded with: {error}" : "Error: el servidor ha respost amb: {error}",
    "Error: Unknown error occurred" : "Error: s'ha produït un error desconegut",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Avís: Versió en execució: {version}; El servidor no admet totes les funcions d'aquesta versió de Converses, les funcions que falten: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "És molt recomanable configurar una memòria cau quan executeu Nextcloud Converses amb un rerefons d'alt rendiment.",
    "Client Push" : "Client Push",
    "Recording backend" : "Rerefons de gravació",
    "Using the recording backend requires a High-performance backend." : "L'ús del rerefons de gravació requereix un rerefons d'alt rendiment.",
    "No recording backend configured" : "No s'ha configurat cap rerefons de gravació",
    "SIP configuration" : "Configuració SIP",
    "Using the SIP functionality requires a High-performance backend." : "L'ús de la funcionalitat SIP requereix un rerefons d'alt rendiment.",
    "No SIP backend configured" : "No s'ha configurat cap rerefons SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Data no vàlida, el format de la data ha de ser YYYY-MM-DD",
    "Conversation not found" : "No s'ha trobat la conversa",
    "Path is already shared with this conversation" : "El camí ja s'ha compartit amb aquesta conversa",
    "Chat, video & audio-conferencing using WebRTC" : "Xat, àudio i vídeo-conferència emprant WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Xat, vídeo i àudio-conferència mitjançant WebRTC\n\n* 💬 **Xat** Nextcloud Converses inclou un xat de text senzill, que us permet compartir o carregar fitxers des de la vostra aplicació Nextcloud Fitxers o dispositiu local i esmentar altres participants.\n* 👥 **Trucades privades, de grup, públiques i protegides amb contrasenya!** Convida algú, un grup sencer o envia un enllaç públic per convidar a una trucada.\n* 🌐 **Xats federats** Xateja amb altres usuaris de Nextcloud als seus servidors\n* 💻 **Compartició de pantalla!** Comparteix la teva pantalla amb els participants de la trucada.\n* 🚀 **Integració amb altres aplicacions de Nextcloud** com Fitxers, Calendari, Estat de l'usuari, Tauler, Flow, Maps, Selector intel·ligent, Contactes, Targetes i molts més.\n* 🌉 **Sincronització amb altres solucions de xat** Amb [Matterbridge](https://github.com/42wim/matterbridge/) integrat a Converses, podeu sincronitzar fàcilment moltes altres solucions de xat amb Nextcloud Converses i viceversa.",
    "Leave call" : "Abandona la trucada",
    "Navigating away from the page will leave the call in {conversation}" : "La navegació fora de la pàgina deixarà la trucada a {conversation}",
    "Stay in call" : "Estigues a la trucada",
    "Duplicate session" : "Sessió duplicada",
    "Discuss this file" : "Discuteix aquest fitxer",
    "Loading …" : "S'està carregant…",
    "Share this file with others to discuss it" : "Comparteix aquest fitxer amb altres persones per discutir-ho",
    "Join conversation" : "Uneix-te a la conversa",
    "Share this file" : "Comparteix aquest fitxer",
    "Error occurred when joining the conversation" : "S'ha produït un error en unir-se a la conversa",
    "This conversation is password-protected." : "Aquesta conversa està protegida amb contrasenya.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Hem detectat diversos intents de contrasenya no vàlids des de la teva IP. Per tant, el vostre proper intent s'accelera fins a 30 segons.",
    "The password is wrong. Try again." : "La contrasenya no és correcta. Torneu-ho a provar.",
    "Password" : "Contrasenya",
    "Submit" : "Envia",
    "Error requesting the password." : "No s'ha pogut sol·licitar la contrasenya.",
    "Request password" : "Sol·licita contrasenya",
    "This conversation has ended" : "Aquesta conversa s'ha acabat",
    "Close Talk sidebar" : "Tanca la barra lateral de Talk",
    "Open Talk sidebar" : "Obriu la barra lateral de Talk",
    "Everyone" : "Tothom",
    "Users and moderators" : "Usuaris i moderadors",
    "Moderators only" : "Només els moderadors",
    "Disable calls" : "Inhabilita les trucades",
    "Save changes" : "Desa els canvis",
    "Saving …" : "S'està desant …",
    "Saved!" : "Desat!",
    "Limit to groups" : "Limita a grups",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Quan al menys s'ha seleccionat un grup, només les persones dels grups llistats poden participar a les converses.",
    "Guests can still join public conversations." : "Els convidats però poden sumar-se a les converses públiques.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Els usuaris que ja no puguin utilitzar Talk continuaran apareixent com a participants de les seves converses anteriors i també es conservaran els seus missatges de xat.",
    "Limit using Talk" : "Limita l'ús de Talk",
    "Limit creating a public and group conversation" : "Limitar la creació d'una conversa pública i de grup",
    "Limit creating conversations" : "Limita la creació de converses",
    "Limit starting a call" : "Limitar l'inici d'una trucada",
    "Limit starting calls" : "Limitar l’iniciació de trucades",
    "When a call has started, everyone with access to the conversation can join the call." : "Quan ha començat una trucada, tothom que tingui accés a la conversa pot afegir-s'hi.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Els robots següents estan instal·lats en aquest servidor. A la documentació podeu trobar detalls sobre com {linkstart1}crear el vostre propi robot{linkend} o una {linkstart2}llista de robots{linkend} per habilitar-los al vostre servidor.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Els robots següents estan instal·lats en aquest servidor. A la documentació podeu trobar detalls sobre com {linkstart1}crear el vostre propi robot{linkend} o una {linkstart2}llista de robots{linkend} per habilitar-los al vostre servidor.",
    "Description is not provided" : "No es proporciona la descripció",
    "Locked for moderators" : "Bloquejat per als moderadors",
    "Enabled" : "Habilitat",
    "Disabled" : "Inhabilitat",
    "Bots settings" : "Paràmetres dels bots",
    "State" : "Estat",
    "Name" : "Nom",
    "Last error" : "Últim error",
    "Total errors count" : "Nombre d’errors totals",
    "Find more bots" : "Trobeu més robots",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Els servidors de confiança es poden configurar a la {linkstart}pàgina de configuració per compartir{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Els xats i les trucades federades ja funcionen. La gestió dels fitxers adjunts arribarà en una versió futura.",
    "Enable Federation in Talk app" : "Activa la federació a l'aplicació Converses",
    "Permissions" : "Permisos",
    "Allow users to be invited to federated conversations" : "Permet que els usuaris siguin convidats a converses federades",
    "Allow users to invite federated users into conversation" : "Permet als usuaris convidar usuaris federats a una conversa",
    "Only allow to federate with trusted servers" : "Només permet federar-se amb servidors de confiança",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Quan se selecciona almenys un grup, només les persones dels grups llistats poden convidar usuaris federats a converses.",
    "Groups allowed to invite federated users" : "Els grups poden convidar usuaris federats",
    "Select groups …" : "Selecció de grups …",
    "All messages" : "Tots els missatges",
    "@-mentions only" : "només mencions amb @",
    "Off" : "Apagat",
    "General settings" : "Paràmetres generals",
    "Default notification settings" : "Paràmetres de notificacions per defecte",
    "Default group notification" : "Notificació de grup per defecte",
    "Default group notification for new groups" : "Notificació de grup per defecte per a grups nous",
    "Integration into other apps" : "Integració en altres aplicacions",
    "Allow conversations on files" : "Permet converses en fitxers",
    "Allow conversations on public shares for files" : "Permetre converses en comparticions públiques per a fitxers",
    "End-to-end encrypted calls" : "Trucades xifrades d'extrem a extrem",
    "Enable encryption" : "Habilita el xifratge",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Les trucades xifrades d'extrem a extrem amb un pont SIP configurat requereixen una versió més recent del rerefons d'alt rendiment i del pont SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Els clients mòbils no admeten trucades xifrades d'extrem a extrem de moment.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "En fer clic al botó que hi ha a sobre de la informació del formulari s'envia als servidors de Struktur AG. Podeu trobar més informació a {linkstart}spreed.eu{linkend}.",
    "Pending" : "Pendent",
    "Error" : "Error",
    "Blocked" : "Blocat",
    "Active" : "Actiu",
    "Expired" : "Caducat",
    "Never" : "Mai",
    "The trial could not be requested. Please try again later." : "No s'ha pogut sol·licitar la prova. Torneu-ho a provar més tard.",
    "The account could not be deleted. Please try again later." : "No s'ha pogut suprimir el compte. Torneu-ho a provar més tard.",
    "Hosted High-performance backend" : "Servidor rerefons d'alt rendiment",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "El nostre soci Struktur AG ofereix un servei on es pot sol·licitar un servidor de senyalització allotjat. Per a això només has d'omplir el següent formulari i el teu Nextcloud ho sol·licitarà. Un cop configurat el servidor, les credencials s'ompliran automàticament. Això sobreescriurà els paràmetres del servidor de senyalització existent.",
    "URL of this Nextcloud instance" : "URL d'aquesta instància de Nextcloud",
    "Full name of the user requesting the trial" : "Nom complet de l'usuari que sol·licita la prova",
    "Email of the user" : "Enviar correu electrònic al nou usuari",
    "Language" : "Llengua",
    "Country" : "País",
    "Request signaling server trial" : "Sol·licita la prova del servidor de senyalització",
    "You can see the current status of your hosted signaling server in the following table." : "Podeu veure l'estat actual del servidor de senyalització allotjat a la taula següent.",
    "Status" : "Estat",
    "Created at" : "Creat a",
    "Expires at" : "Venciment el",
    "Limits" : "Límits",
    "Yes" : "Sí",
    "No" : "No",
    "Delete the signaling server account" : "Suprimeix el compte del servidor de senyalització",
    "_%n user_::_%n users_" : ["%n usuari","%n usuaris"],
    "Installed version: {version}" : "Versió instal·lada: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Podeu instal·lar Matterbridge per enllaçar Nextcloud Talk amb altres serveis, visiteu la seva {linkstart1}pàgina de GitHub{linkend} per obtenir més informació. Descarregar i instal·lar l'aplicació pot trigar una estona. En cas que s'acabi, instal·leu-lo manualment des de la {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "El binari de Matterbridge té permisos incorrectes. Assegureu-vos que el fitxer binari Matterbridge és propietat de l'usuari correcte i es pot executar. Es pot trobar a \"/.../nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "No s'ha trobat el binari de Matterbridge o no s'ha pogut executar.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "També podeu establir el camí cap al binari de Matterbridge manualment a través de la configuració. Comproveu la {linkstart}documentació d'integració de Matterbridge{linkend} per obtenir més informació.",
    "Downloading …" : "S'està baixant …",
    "Install Talk Matterbridge" : "Instal·la Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "S'ha produït un error en instal·lar l'aplicació Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "S'ha produït un error en instal·lar el Parla Matterbridge. Si us plau, instal·leu-lo manualment",
    "Failed to execute Matterbridge binary." : "No s'ha pogut executar el binari de Matterbridge.",
    "Matterbridge integration" : "Integració de Matterbridge",
    "Enable Matterbridge integration" : "Habilita la integració de Matterbridge",
    "Status: Checking connection" : "Estat: Comprovant la connexió",
    "OK: Running version: {version}" : "D'acord: versió en execució: {version}",
    "Error: Server seems to be a Signaling server" : "Error: el servidor sembla ser un servidor de senyalització",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Error: els temps del sistema del servidor Nextcloud i el servidor de fons de gravació no estan sincronitzats. Assegureu-vos que tots dos servidors estiguin connectats a un servidor d'hora o sincronitzeu manualment la seva hora.",
    "Recording backend URL" : "Enregistrament de l'URL del rerefons",
    "Validate SSL certificate" : "Validar certificat SSL",
    "Delete this server" : "Suprimeix aquest servidor",
    "Test this server" : "Prova aquest servidor",
    "Disabled for all calls" : "Desactivat per a totes les trucades",
    "Enabled for all calls" : "Habilitat per a totes les trucades",
    "Configurable on conversation level by moderators" : "Configurable a nivell de conversa pels moderadors",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Els paràmetres de PHP \"upload_max_filesize\" o \"post_max_size\" només permetrà carregar fitxers fins a {maxUpload}.",
    "Recording backend settings saved" : "S'ha desat el paràmetre del rerefons de gravació",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Els moderadors podran habilitar el consentiment a nivell de conversa. El consentiment per ser gravat serà necessari per a cada participant abans d'unir-se a cada trucada d'aquesta conversa.",
    "The consent to be recorded will be required for each participant before joining every call." : "El consentiment per ser gravat serà necessari per a cada participant abans d'unir-se a cada trucada.",
    "The consent to be recorded is not required." : "No cal el consentiment per ser gravat.",
    "Recording backend configuration is only possible with a High-performance backend." : "La configuració del rerefons de gravació només és possible amb un rerefons d'alt rendiment.",
    "Add a new recording backend server" : "Afegiu un nou servidor de rerefons de gravació",
    "Shared secret" : "Clau secreta compartida",
    "Recording consent" : "Consentiment de gravació",
    "Recording transcription" : "Enregistrament de la transcripció",
    "Automatically transcribe call recordings with a transcription provider" : "Transcriu automàticament els enregistraments de trucades amb un proveïdor de transcripcions",
    "Automatically summarize call recordings with transcription and summary providers" : "Resumeix automàticament els enregistraments de trucades amb proveïdors de transcripció i resum",
    "SIP configuration saved!" : "Configuració SIP desada!",
    "SIP configuration is only possible with a High-performance backend." : "La configuració SIP només és possible amb un rerefons d'alt rendiment.",
    "Enable SIP Dial-out option" : "Habilita l'opció de marcatge SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "El servidor de senyalització s'ha d'actualitzar a la funció de marcatge SIP compatible.",
    "Restrict SIP configuration" : "Restringeix la configuració SIP",
    "Enable SIP configuration" : "Habilita la configuració SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Només els usuaris dels grups següents poden habilitar SIP a les converses que moderin",
    "Phone number (Country)" : "Número de telèfon (País)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Aquesta informació s'envia als correus electrònics d'invitació i es mostra a la barra lateral a tots els participants.",
    "Nextcloud base URL" : "URL base de Nextcloud",
    "Talk Backend URL" : "URL del rerefons de Converses",
    "WebSocket URL" : "URL de WebSocket",
    "Available features" : "Funcions disponibles",
    "Error: Websocket connection failed. Check browser console" : "Error: la connexió de Websocket ha fallat. Comproveu la consola del navegador",
    "High-performance backend URL" : "URL del rerefons d'alt rendiment",
    "Missing High-performance backend warning hidden" : "Falta l'advertiment de rerefons d'alt rendiment amagat",
    "High-performance backend settings saved" : "S'ha desat els paràmetres del rerefons d'alt rendiment",
    "Nextcloud Talk setup not complete" : "La configuració de Nextcloud Converses no s'ha completat",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Tingueu en compte que a les trucades amb més de 2 participants sense el rerefons d'alt rendiment, és probable que els participants experimentin problemes de connectivitat i causen una càrrega elevada als dispositius participants.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Instal·leu el rerefons d'alt rendiment per garantir que les trucades amb diversos participants funcionin perfectament.",
    "Nextcloud portal" : "Portal Nextcloud",
    "Quick installation guide" : "Guia d'instal·lació ràpida",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "El rerefons d'alt rendiment és necessari per a trucades i converses amb diversos participants. Sense el rerefons, tots els participants han de penjar el seu propi vídeo individualment per a cada altre participant, cosa que probablement causarà problemes de connectivitat i una càrrega elevada als dispositius participants.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "És molt recomanable configurar una memòria cau distribuïda quan utilitzeu Nextcloud Talk amb un rerefons d'alt rendiment.",
    "Add High-performance backend server" : "Afegiu un servidor rerefons d'alt rendiment",
    "Warn about connectivity issues in calls with more than 2 participants" : "Adverteix sobre problemes de connectivitat a les trucades amb més de 2 participants",
    "STUN server URL" : "URL del servidor STUN",
    "The server address is invalid" : "L'adreça del servidor no és vàlida",
    "STUN settings saved" : "S'han desat els paràmetres de STUN",
    "STUN servers" : "Servidors STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "S'utilitza un servidor STUN per determinar l'adreça IP pública dels participants que siguin darrera d'un router.",
    "Add a new STUN server" : "Afegeix un nou servidor STUN",
    "{schema} scheme must be used with a domain" : "L'esquema {schema} s'ha d'utilitzar amb un domini",
    "{option1} and {option2}" : "{option1} i {option2}",
    "{option} only" : "Només {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "D'acord: Els candidats de l'ICE reeixits retornats pel servidor TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Error: no hi ha candidats de l'ICE que funcionin retornats pel servidor TURN",
    "Testing whether the TURN server returns ICE candidates" : "S'està provant si el servidor TURN retorna els candidats de l'ICE",
    "TURN server schemes" : "Esquemes del servidor TURN",
    "TURN server URL" : "URL del servidor TURN",
    "TURN server secret" : "Paràmetre \"secret\" del servidor TURN",
    "TURN server protocols" : "Protocols del servidor TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "S'utilitza un servidor TURN per enviar el trànsit dels participants darrere d'un tallafoc. Si els participants individuals no poden connectar-se amb altres, probablement es requereixi un servidor TURN. Consulteu {linkstart}aquesta documentació{linkend} per obtenir instruccions de configuració.",
    "TURN settings saved" : "S'han desat els paràmetres de TURN",
    "TURN servers" : "Servidors TURN",
    "Add a new TURN server" : "Afegeix un nou servidor TURN",
    "Failed" : "Ha fallat",
    "OK" : "D'acord",
    "Checking …" : "Comprovant …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Error: WebAssembly està desactivat o no és compatible amb aquest navegador. Si us plau, habiliteu WebAssembly o utilitzeu un navegador amb suport per fer la comprovació.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Error: el servidor web no ha retornat correctament els fitxers \".wasm\" i \".tflite\". Consulteu la secció \"Requisits del sistema\" a la documentació de Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "D'acord: el servidor web ha retornat correctament els fitxers \".wasm\" i \".tflite\".",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Sembla que la configuració de PHP i Apache no és compatible. Tingueu en compte que PHP només es pot utilitzar amb el mòdul MPM_PREFORK i PHP-FPM només es pot utilitzar amb el mòdul MPM_EVENT.",
    "Web server setup checks" : "Comprovacions de configuració del servidor web",
    "Files required for virtual background can be loaded" : "Es poden carregar els fitxers necessaris per al fons virtual",
    "Federated user" : "Usuari federat",
    "Assign participants to rooms" : "Assigna els participants a les sales",
    "Configure breakout rooms" : "Configura les sales de treball",
    "Number of breakout rooms" : "Nombre de sales de treball",
    "You can create from 1 to 20 breakout rooms." : "Pots crear d'1 a 20 sales de treball.",
    "Assignment method" : "Mètode d'assignació",
    "Automatically assign participants" : "Assigna participants automàticament",
    "Manually assign participants" : "Assigna els participants manualment",
    "Allow participants to choose" : "Permet als participants triar",
    "Create rooms" : "Crea sales",
    "Confirm" : "Confirma",
    "Create breakout rooms" : "Crea sales de treball",
    "Reset" : "Restableix",
    "Delete breakout rooms" : "Suprimeix les sales de treball",
    "Room {roomNumber}" : "Sala {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Es perdran les sales de treball i els paràmetres actuals",
    "Cancel" : "Cancelar",
    "Unassigned participants" : "Participants no assignats",
    "Back" : "Enrere",
    "Assign" : "Assigna",
    "Add participant \"{user}\"" : "Afegeix el participant \"{user}\"",
    "Now" : "Ara",
    "Invalid calendar selected" : "S'ha seleccionat un calendari no vàlid",
    "Invalid start time selected" : "L'hora d'inici seleccionada no és vàlida",
    "Invalid end time selected" : "L'hora de finalització seleccionada no és vàlida",
    "Unknown error occurred" : "S'ha produït un error desconegut",
    "Sending no invitations" : "No s'envia cap invitació",
    "{participant0} will receive an invitation" : "{participant0} rebrà una invitació",
    "{participant0} and {participant1} will receive invitations" : "{participant0} i {participant1} rebran invitacions",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} i %n més rebran invitacions","{participant0}, {participant1} i %n més rebran invitacions"],
    "Meeting created" : "Reunió creada",
    "Upcoming meetings" : "Properes reunions",
    "Schedule a meeting" : "Programar una reunió",
    "Meeting title" : "Títol de la reunió",
    "From" : "De",
    "To" : "A",
    "Calendar" : "Calendari",
    "Attendees" : "Assistents",
    "Add attendees" : "Afegeix assistents",
    "Save" : "Desa",
    "Search participants" : "Cercar participants",
    "No results" : "No hi ha resultats",
    "Done" : "Desat",
    "Exit full screen (F)" : "Sortir de la pantalla completa (F)",
    "Full screen (F)" : "Pantalla completa (F)",
    "Speaker view" : "Visualització de qui parla",
    "Grid view" : "Vista de graella",
    "Recording consent is required" : "Cal el consentiment de gravació",
    "This conversation is read-only" : "Aquesta conversa és només de lectura",
    "Conversation not found or not joined" : "No s'ha trobat la conversa o no s'ha unit",
    "Lobby is still active and you're not a moderator" : "El vestíbul encara està actiu i no ets moderador",
    "Connection failed" : "Ha fallat la connexió",
    "Reload" : "Recarrega",
    "{nickName} raised their hand." : "{nickName} va aixecar la mà.",
    "A participant raised their hand." : "Un participant va aixecar la mà.",
    "Collapse stripe" : "Col·lapse la franja",
    "Expand stripe" : "Ampliar la franja",
    "Previous page of videos" : "Pàgina anterior de vídeos",
    "Next page of videos" : "Següent pàgina de vídeos",
    "Connecting …" : "S'està connectant …",
    "Calling …" : "S'està trucant …",
    "Waiting for {user} to join the call" : "S'està esperant que {user} s'uneixi a la trucada",
    "Waiting for others to join the call …" : "Esperant a la resta per realitzar la trucada …",
    "You can invite others in the participant tab of the sidebar" : "Podeu convidar més gent des de la pestanya Participants al panell lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Podeu convidar a més gent des de la pestanya Participants al panell lateral o compartint aquest enllaç a tercers!",
    "Share this link to invite others!" : "Compartiu aquest enllaç per convidar a més gent!",
    "Copy link" : "Copia l'enllaç",
    "You are not allowed to enable audio" : "No teniu permís per activar l'àudio",
    "No audio. Click to select device" : "Sense àudio. Feu clic per seleccionar el dispositiu",
    "Mute audio" : "Silencia l'àudio",
    "Mute audio (M)" : "Silencia l'àudio (m)",
    "Unmute audio" : "Activa l'àudio",
    "Unmute audio (M)" : "Re-activa l'àudio (m)",
    "None" : "Cap",
    "Access to camera was denied" : "S'ha denegat l'accés a la càmera",
    "Error while accessing camera: It is likely in use by another program" : "Error en accedir a la càmera: és probable que l'utilitzi un altre programa",
    "Error while accessing camera" : "S'ha produït un error en accedir a la càmera",
    "You have been muted by a moderator" : "Vostè ha estat silenciat per un moderador",
    "Hide presenter video" : "Amaga el vídeo del presentador",
    "You are not allowed to enable video" : "No tens permís per activar el vídeo",
    "No video. Click to select device" : "Cap vídeo. Feu clic per seleccionar el dispositiu",
    "Disable video" : "Inhabilita el vídeo",
    "Disable video (V)" : "Inhabilita el vídeo (v)",
    "Enable video" : "Habilita el vídeo",
    "Enable video (V)" : "Habilita el vídeo (v)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Activa el vídeo. La connexió s'interromprà breument en habilitar el vídeo per primera vegada",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Habilita el vídeo (V) - La vostra connexió s'interromprà quan s'activeu el vídeo per primera vegada",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Activa el vídeo. La connexió s'interromprà breument en habilitar el vídeo per primera vegada",
    "Show presenter" : "Mostra presentador",
    "You" : "Tu",
    "Mute" : "Silencia",
    "Muted" : "Silenciat",
    "Show screen" : "Mostra la pantalla",
    "Stop following" : "Deixa de seguir",
    "Connection could not be established …" : "No s'ha pogut establir la connexió …",
    "Connection was lost and could not be re-established …" : "La connexió es va perdre i no es va poder restablir …",
    "Connection could not be established. Trying again …" : "No s'ha pogut establir la connexió. Tornant a provar …",
    "Connection lost. Trying to reconnect …" : "Connexió perduda. S'està intentant tornar a connectar …",
    "Connection problems …" : "Problemes de connexió …",
    "Collapse" : "Replega",
    "Expand" : "Expandeix",
    "You need to be logged in to upload files" : "Heu d'iniciar la sessió per pujar fitxers",
    "Drop your files to upload" : "Deixeu anar els fitxers per pujar-los",
    "Conversation messages" : "Missatges de conversa",
    "Scroll to bottom" : "Desplaça al final",
    "Post message" : "Publica el missatge",
    "Federated conversation" : "Conversa federada",
    "Public conversation" : "Conversa pública",
    "Favorite" : "Preferit",
    "Banned users" : "Usuaris prohibits",
    "Manage the list of banned users in this conversation." : "Gestioneu la llista d'usuaris prohibits en aquesta conversa.",
    "Manage bans" : "Gestionar les prohibicions",
    "No banned users" : "No hi ha usuaris prohibits",
    "Banned by:" : "Prohibit per:",
    "Date:" : "Data:",
    "Note:" : "Nota:",
    "Hide details" : "Amaga els detalls",
    "Show details" : "Mostra els detalls",
    "Unban" : "Anul·la la prohibició",
    "Error while updating conversation name" : "S'ha produït un error en actualitzar el nom de la conversa",
    "Error while updating conversation description" : "S'ha produït un error en actualitzar la descripció de la conversa",
    "Enter a name for this conversation" : "Introduïu un nom per a la nova conversa",
    "Edit conversation name" : "Edició del nom de la conversa",
    "Edit conversation description" : "Edició de la descripció de la conversa",
    "Enter a description for this conversation" : "Introdueix una descripció per a aquesta conversa",
    "Picture" : "Imatge",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Els robots següents es poden habilitar en aquesta conversa. Poseu-vos en contacte amb la vostra administració per instal·lar més robots en aquest servidor.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "No hi ha cap robot instal·lat en aquest servidor. Poseu-vos en contacte amb la vostra administració per instal·lar robots en aquest servidor.",
    "Disable" : "Inhabilitar",
    "Enable" : "Habilitar",
    "Breakout rooms" : "Sales de treball",
    "Manage breakout rooms" : "Gestiona les sales de treball",
    "Set up breakout rooms for this conversation" : "Configura sales de treball per a aquesta conversa",
    "Please select a valid PNG or JPG file" : "Seleccioneu un fitxer PNG o JPG vàlid",
    "Choose your conversation picture" : "Tria la teva imatge de conversa",
    "Choose" : "Tria",
    "Error setting conversation picture" : "S'ha produït un error en establir la imatge de la conversa",
    "Could not set the conversation picture: {error}" : "No s'ha pogut configurar la imatge de la conversa: {error}",
    "Error cropping conversation picture" : "S'ha produït un error en retallar la imatge de la conversa",
    "Error removing conversation picture" : "S'ha produït un error en eliminar la imatge de la conversa",
    "Set emoji as conversation picture" : "Estableix l'emoticona com a imatge de conversa",
    "Set background color for conversation picture" : "Estableix el color de fons per a la imatge de la conversa",
    "Upload conversation picture" : "Pujar la imatge de la conversa",
    "Choose conversation picture from files" : "Trieu la imatge de la conversa dels fitxers",
    "Remove conversation picture" : "Suprimir la imatge de la conversa",
    "The file must be a PNG or JPG" : "El fitxer ha de ser PNG o JPG",
    "Set picture" : "Estableix la imatge",
    "Default permissions modified for {conversationName}" : "Permisos per defecte modificats per a {conversationName}",
    "Could not modify default permissions for {conversationName}" : "No s'han pogut modificar els permisos per defecte per a {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Editeu els paràmetres predeterminats dels participants en aquesta conversa. Aquesta configuració no afecta els moderadors.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Cada vegada que es modifiquin els permisos en aquesta secció, es perdran els permisos personalitzats assignats prèviament als participants individuals.",
    "All permissions" : "Tots els permisos",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Els participants tenen permisos per iniciar una trucada, unir-se a una trucada, habilitar l'àudio i el vídeo i compartir la pantalla.",
    "Restricted" : "Restringit",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Els participants poden unir-se a les trucades, però no poden habilitar l'àudio ni el vídeo ni compartir la pantalla fins que un moderador els concedeixi manualment els permisos.",
    "Advanced permissions" : "Permisos avançats",
    "Edit permissions" : "Edició dels permisos",
    "Conversation settings" : "Paràmetres de la conversa",
    "Basic Info" : "Informació bàsica",
    "Personal" : "Personal",
    "Moderation" : "Moderació",
    "Setup overview" : "Visió general de la configuració",
    "Breakout Rooms" : "Sales de treball",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Robots",
    "Danger zone" : "Zona perillosa",
    "Archive conversation" : "Arxiva la conversa",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Les converses arxivades s'oculten de la llista de converses de manera predeterminada. Tanmateix, encara apareixeran quan cerqueu el nom de la conversa o accediu a una llista de converses arxivades.",
    "Do you really want to leave \"{displayName}\"?" : "De veritat voleu deixar \"{displayName}\"?",
    "You can archive this conversation instead." : "Pots arxivar aquesta conversa.",
    "Leave conversation" : "Surt de la conversa",
    "You need to promote a new moderator before you can leave the conversation" : "Heu de promocionar un nou moderador abans de deixar la conversa",
    "Delete conversation" : "Suprimeix la conversa",
    "Do you really want to delete \"{displayName}\"?" : "De debò que voleu suprimir \"{displayName}\"?",
    "Error while deleting conversation" : "S'ha produït un error en suprimir la conversa",
    "Delete all chat messages" : "Suprimeix tots els missatges de xat",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Realment voleu suprimir tots els missatges de \"{displayName}\"?",
    "Error while clearing chat history" : "S'ha produït un error en esborrar l'historial de xat",
    "Be careful, these actions cannot be undone." : "Aneu amb compte, aquestes accions no es poden desfer.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un cop acabada una conversa, per tornar a unir-se a una conversa tancada, cal una invitació. Es pot unir de nou a una conversa oberta en qualsevol moment.",
    "Permanently delete this conversation." : "Suprimeix permanentment aquesta conversa.",
    "Delete chat messages" : "Suprimeix els missatges de xat",
    "Permanently delete all the messages in this conversation." : "Suprimeix permanentment tots els missatges d'aquesta conversa.",
    "Custom expiration time" : "Temps de caducitat personalitzat",
    "Message expiration disabled" : "S'ha desactivat la caducitat del missatge",
    "Message expiration set: {duration}" : "Conjunt de caducitat del missatge: {duration}",
    "Error when trying to set message expiration" : "S'ha produït un error en intentar configurar la caducitat del missatge",
    "Message expiration" : "Caducitat del missatge",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Els missatges de xat poden caducar al cap d'un període de temps determinat. Nota: els fitxers compartits al xat no se suprimiran per al propietari, però ja no es compartiran a la conversa.",
    "Set message expiration" : "Estableix la caducitat del missatge",
    "Current message expiration" : "Caducitat del missatge actual",
    "Password copied to clipboard" : "S’ha copiat la contrasenya al porta-retalls",
    "Password could not be copied" : "No s'ha pogut copiar la contrasenya",
    "Guest access" : "Accés de convidat",
    "Breakout rooms are not allowed in public conversations." : "No es permeten les sales de descans en converses públiques.",
    "Allow guests to join this conversation via link" : "Permet als convidats unir-se a aquesta conversa mitjançant un enllaç",
    "Password protection" : "Protecció amb contrasenya",
    "This conversation is password-protected. Guests need password to join" : "Aquesta conversa està protegida amb contrasenya. Els convidats necessiten una contrasenya per unir-se",
    "Password protection is needed for public conversations" : "La protecció amb contrasenya és necessària per a les converses públiques",
    "Set a password" : "Configura una contrasenya",
    "Enter new password" : "Introduïu la contrasenya nova",
    "Save password" : "Desa la contrasenya",
    "Copy password" : "Copia la contrasenya",
    "Guests are allowed to join this conversation via link" : "Els convidats poden unir-se a aquesta conversa mitjançant un enllaç",
    "Guests are not allowed to join this conversation" : "Els convidats no poden unir-se a aquesta conversa",
    "Resend invitations" : "Torna a enviar les invitacions",
    "This conversation is open to both registered users and users created with the Guests app" : "Aquesta conversa és oberta tant als usuaris registrats com als usuaris creats amb l'aplicació Convidats",
    "This conversation is open to registered users" : "Aquesta conversa és oberta als usuaris registrats",
    "This conversation is limited to the current participants" : "Aquesta conversa està limitada als participants actuals",
    "You opened the conversation to both registered users and users created with the Guests app" : "Has obert la conversa tant als usuaris registrats com als usuaris creats amb l'aplicació Convidats",
    "Error occurred when opening or limiting the conversation" : "S'ha produït un error en obrir o limitar la conversa",
    "Open conversation to registered users, showing it in search results" : "Conversa oberta als usuaris registrats, mostrant-la als resultats de la cerca",
    "Also open to users created with the Guests app" : "També obert als usuaris creats amb l'aplicació Convidats",
    "Open conversation" : "Obre Conversa",
    "Invalid language" : "La llengua no és vàlida",
    "Start time: {date}" : "Hora d'inici: {date}",
    "Start time has been updated" : "S'ha actualitzat l'hora d'inici",
    "Error occurred while updating start time" : "S'ha produït un error en actualitzar l'hora d'inici",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Si habiliteu el vestíbul, els no moderadors es suprimiran de la trucada en curs.",
    "Enable lobby, restricting the conversation to moderators" : "Habilitar el vestíbul, restringint la conversa als moderadors",
    "Meeting start time" : "Hora d'inici de la reunió",
    "Start time (optional)" : "Hora d'inici (opcional)",
    "Import email participants" : "Importa els participants del correu electrònic",
    "You can import a list of email participants from a CSV file." : "Podeu importar una llista de participants de correu electrònic des d'un fitxer CSV.",
    "Poll drafts" : "Esborranys d'enquestes",
    "Browse poll drafts" : "Consulta els esborranys de les enquestes",
    "Error occurred when locking the conversation" : "S'ha produït un error en bloquejar la conversa",
    "Error occurred when unlocking the conversation" : "S'ha produït un error en desbloquejar la conversa",
    "Lock conversation" : "Bloqueja la conversa",
    "This will also terminate the ongoing call." : "Això també finalitzarà la trucada en curs.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloqueja la conversa per evitar que ningú publiqui missatges o iniciï trucades",
    "Edit" : "Edició",
    "More information" : "Més informació",
    "Delete" : "Suprimir",
    "Add new bridged channel to current conversation" : "Afegeix un nou canal connectat a la conversa actual",
    "unknown state" : "estat desconegut",
    "running" : "en execució",
    "not running, check Matterbridge log" : "no funciona, comproveu el registre de Matterbridge",
    "not running" : "no s'està executant",
    "Bridge saved" : "Pont desat",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Podeu fer ponts des de diversos sistemes de missatgeria instantània amb Matterbridge.",
    "More info on Matterbridge" : "Més informació sobre Matterbridge",
    "Messaging systems" : "Sistemes de missatgeria",
    "Enable bridge" : "Habilitar el pont",
    "Show Matterbridge log" : "Mostra el registre de Matterbridge",
    "Log content" : "Contingut del registre",
    "Only moderators are allowed to mention @all" : "Només els moderadors poden esmentar @all",
    "All participants are allowed to mention @all" : "Tots els participants poden esmentar @all",
    "Participants are now allowed to mention @all." : "Ara els participants poden esmentar @all.",
    "Mentioning @all has been limited to moderators." : "Esmentar @all s'ha limitat als moderadors.",
    "Allow participants to mention @all" : "Permet als participants mencionar @all",
    "Mention permissions" : "Esmenta els permisos",
    "Notifications" : "Notificacions",
    "Notify about calls in this conversation" : "Notifica quant a trucades en aquesta conversa",
    "Important conversation" : "Conversa important",
    "Recording consent is required for calls in this conversation" : "Cal el consentiment per gravar les trucades d'aquesta conversa",
    "Recording consent is not required for calls in this conversation" : "No cal el consentiment per gravar les trucades d'aquesta conversa",
    "Recording consent requirement was updated" : "S'ha actualitzat el requisit de consentiment de gravació",
    "Error occurred while updating recording consent" : "S'ha produït un error en actualitzar el consentiment de gravació",
    "Recording Consent" : "Consentiment de gravació",
    "Recording consent cannot be changed once a call or breakout session has started." : "El consentiment de gravació no es pot canviar un cop s'ha iniciat una trucada o una sessió grupal.",
    "Require recording consent before joining call in this conversation" : "Requereix el consentiment per gravar abans d'unir-te a la trucada en aquesta conversa",
    "Recording consent is required for all calls" : "Cal el consentiment de gravació per a totes les trucades",
    "SIP dial-in is now possible without PIN requirement" : "Ara és possible l'accés SIP sense necessitat de PIN",
    "SIP dial-in is now enabled" : "Ara s'ha habilitat el marcatge SIP",
    "SIP dial-in is now disabled" : "El marcatge SIP ara està desactivat",
    "Error occurred when enabling SIP dial-in" : "S'ha produït un error en activar el telèfon d'entrada SIP",
    "Error occurred when disabling SIP dial-in" : "S'ha produït un error en desactivar el telèfon d'entrada SIP",
    "Phone and SIP dial-in" : "Telèfon i marcatge SIP",
    "Enable phone and SIP dial-in" : "Habilita el telèfon i el trucades SIP",
    "Allow to dial-in without a PIN" : "Permet marcar sense un PIN",
    "Join" : "Uneix-te",
    "Error while creating the conversation" : "Error en crear la conversa",
    "Create a new conversation" : "Crea una conversa nova",
    "Join open conversations" : "Uneix-te a converses obertes",
    "Call a phone number" : "Trucada a un número de telèfon",
    "Unread mentions" : "Mencions no llegides",
    "Create conversation" : "Crea una conversa",
    "Enter your name" : "Introdueix el teu nom",
    "Submit name and join" : "Envia el nom i uneix-te",
    "Do you already have an account?" : "Ja tens un compte?",
    "Log in" : "Inicia la sessió",
    "Error while verifying uploaded file" : "S'ha produït un error en verificar el fitxer penjat",
    "Uploaded file is verified" : "El fitxer penjat està verificat",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "El format del contingut són valors separats per comes (CSV):<br/> - La línia de capçalera és necessària i ha de coincidir amb <samp>\"nom\", \"correu electrònic\"</samp> o només <samp>\"correu electrònic\"</samp><br/> - Una entrada per línia (per exemple, <samp>\"John Doe\",\"john@example.tld\"</samp> )",
    "Participants added successfully" : "Els participants s'han afegit correctament",
    "Error while adding participants" : "S'ha produït un error en afegir participants",
    "Import a file" : "Importa un fitxer",
    "Browse" : "Navegació",
    "Verifying uploaded file …" : "S'està verificant el fitxer penjat …",
    "This might take a moment" : "Això pot trigar un moment",
    "Send invitations" : "Enviar invitacions",
    "_%n invalid email_::_%n invalid emails_" : ["%n correu electrònic no vàlid","%n correus electrònics no vàlids"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["El correu electrònic %n ja s'ha importat o està duplicat","%n correus electrònics ja s'han importat o s'han duplicat"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Es pot enviar %n invitació","Es poden enviar %n invitacions"],
    "An error occurred while calling a phone number" : "S'ha produït un error en trucar a un número de telèfon",
    "Phone number could not be called: {error}" : "No s'ha pogut trucar al número de telèfon: {error}",
    "Phone number could not be called" : "No s'ha pogut trucar al número de telèfon",
    "Search participants or phone numbers" : "Cerca participants o números de telèfon",
    "Creating the conversation …" : "Creació de la conversa …",
    "Mark as read" : "Marca com a llegit",
    "Mark as unread" : "Marca com a sense llegir",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Add to favorites" : "Afegeix a preferits",
    "Unarchive conversation" : "Desarxiva la conversa",
    "You need to promote a new moderator before you can leave the conversation." : "Heu de designar un nou moderador abans de deixar la conversa.",
    "New tag" : "Nova etiqueta",
    "Tag name" : "Nom de l'etiqueta",
    "Conversation actions" : "Accions de conversa",
    "Tags" : "Etiquetes",
    "Notify about calls" : "Notificar sobre trucades",
    "Rename tag" : "Canvia el nom de l'etiqueta",
    "Delete tag" : "Suprimir etiqueta",
    "Move up" : "Mou amunt",
    "Move down" : "Mou avall",
    "Pending invitations" : "Invitacions pendents",
    "From {user} at {remoteServer}" : "Des de les {user} a les {remoteServer}",
    "Decline invitation" : "Rebutja la invitació",
    "Accept invitation" : "Accepta la invitació",
    "No pending invitations" : "No hi ha cap invitació pendent",
    "Home" : "Casa",
    "Unread" : "Per llegir",
    "Alphabetically" : "Alfabèticament",
    "No matches found" : "No s'ha trobat cap coincidència",
    "No conversations found" : "No s'han trobat converses",
    "You have no archived conversations." : "No tens converses arxivades.",
    "You have no unread mentions." : "No tens mencions no llegides.",
    "You have no unread messages." : "No tens missatges no llegits.",
    "An error occurred while performing the search" : "S'ha produït un error en realitzar la cerca",
    "Conversation list" : "Llista de converses",
    "Unread messages" : "Missatges sense llegir",
    "Clear filters" : "Esborra els filtres",
    "New personal note" : "Nova nota personal",
    "Back to conversations" : "Torna a les converses",
    "Archived conversations" : "Converses arxivades",
    "Clear filter" : "Esborra el filtre",
    "Users" : "Usuaris",
    "Groups" : "Grups",
    "Teams" : "Equips",
    "Federated users" : "Afegeix usuaris federats",
    "New private conversation" : "Nova conversa privada",
    "Other sources" : "Altres fonts",
    "Open conversations" : "Obre les converses",
    "No search results" : "No s'han trobat resultats",
    "Users, groups and teams" : "Usuaris, grups i equips",
    "Users and groups" : "Usuaris i grups",
    "Users and teams" : "Usuaris i equips",
    "Groups and teams" : "Grups i equips",
    "New group conversation" : "Nova conversa de grup",
    "The meeting will start soon" : "La reunió començarà aviat",
    "This meeting is scheduled for {startTime}" : "Aquesta reunió està planificada per a les {startTime}",
    "You are currently waiting in the lobby" : "Ara esteu esperant al vestíbul",
    "Advanced" : "Avançat",
    "Select microphone" : "Seleccioneu el micròfon",
    "No microphone available" : "No hi ha micròfon disponible",
    "Select speaker" : "Seleccioneu l'altaveu",
    "No speaker available" : "No hi ha altaveu disponible",
    "Select camera" : "Seleccioni la càmera",
    "No camera available" : "No hi ha cap càmera disponible",
    "Select a device" : "Seleccioneu un dispositiu",
    "Playing …" : "Reproduint …",
    "Test speakers" : "Prova altaveus",
    "Test" : "Prova",
    "Devices" : "Dispositius",
    "Backgrounds" : "Fons",
    "No audio" : "Sense àudio",
    "No camera" : "No càmera",
    "Display video as you will see it (mirrored)" : "Mostra el vídeo tal com el veuràs (reglat)",
    "Display video as others will see it" : "Mostra el vídeo tal com el veuran els altres",
    "Calls are not supported in your browser" : "Les trucades no són compatibles amb el vostre navegador",
    "Access to microphone is only possible with HTTPS" : "L'accés al micròfon només és possible amb HTTPS",
    "Access to microphone was denied" : "S'ha denegat l'accés al micròfon",
    "Error while accessing microphone" : "S'ha produït un error en accedir al micròfon",
    "Access to camera is only possible with HTTPS" : "L'accés a la càmera només és possible amb HTTPS",
    "The call is being recorded." : "La trucada s'està gravant.",
    "The call might be recorded." : "És possible que la trucada sigui gravada.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "La gravació pot incloure la teva veu, el vídeo de la càmera i la pantalla compartida. Cal el vostre consentiment abans d'unir-vos a la trucada.",
    "Give consent to the recording of this call" : "Donar el consentiment per a la gravació d'aquesta trucada",
    "Start recording immediately with the call" : "Comenceu a gravar immediatament amb la trucada",
    "Apply settings" : "Aplica els paràmetres",
    "Select virtual office background" : "Seleccioneu el fons virtual d’oficina",
    "Select virtual home background" : "Seleccioneu el fons virtual a casa",
    "Select virtual abstract background" : "Seleccioneu fons virtual abstracte",
    "Select virtual beach background" : "Seleccioneu el fons virtual de platja",
    "Select virtual park background" : "Seleccioneu el fons virtual de parc",
    "Select virtual theater background" : "Seleccioneu el fons virtual de teatre",
    "Select virtual library background" : "Seleccioneu el fons virtual de biblioteca",
    "Select virtual space station background" : "Seleccioneu el fons virtual de l'estació espacial",
    "Error while uploading the file" : "S'ha produït un error en carregar el fitxer",
    "Select a file" : "Select a file",
    "Invalid path selected" : "Camí seleccionat no vàlid",
    "Select virtual background from file {fileName}" : "Seleccioneu el fons virtual del fitxer {fileName}",
    "Blur" : "Difumina",
    "Upload" : "Pujada",
    "Files" : "Fitxers",
    "(editing)" : "(edició)",
    "(edited)" : "(editat)",
    "The message has expired or has been deleted" : "El missatge ha caducat o s'ha suprimit",
    "Cancel quote" : "Cancel·la la menció",
    "24 hours" : "24 hores",
    "7 days" : "7 dies",
    "Clear reminder – {timeLocale}" : "Esborra el recordatori – {timeLocale}",
    "Edited by {actor}" : "Editat per {actor}",
    "Message text copied to clipboard" : "El text del missatge s'ha copiat al porta-retalls",
    "Message text could not be copied" : "No s'ha pogut copiar el text del missatge",
    "Message forwarded to \"Note to self\"" : "Missatge reenviat a \"Nota per a un mateix\"",
    "Error while forwarding message to \"Note to self\"" : "Error en reenviar el missatge a \"Nota per a un mateix\"",
    "A reminder was successfully removed" : "S'ha eliminat correctament un recordatori",
    "Error occurred when removing a reminder" : "S'ha produït un error en eliminar un recordatori",
    "A reminder was successfully set at {datetime}" : "S'ha establert un recordatori correctament a {datetime}",
    "Error occurred when creating a reminder" : "S'ha produït un error en crear un recordatori",
    "Add a reaction to this message" : "Afegeix una reacció a aquest missatge",
    "Reply" : "Respon",
    "More actions" : "Més accions",
    "Set reminder" : "Defineix un recordatori",
    "Reply privately" : "Respon en privat",
    "Edit message" : "Edició del missatge",
    "Copy message" : "Copia el missatge",
    "Copy message link" : "Copia l'enllaç del missatge",
    "Go to file" : "Vés al fitxer",
    "Download file" : "Baixa el fitxer",
    "Forward message" : "Missatge de reenviament",
    "Translate" : "Traducció",
    "Set custom reminder" : "Estableix un recordatori personalitzat",
    "Close reactions menu" : "Tanca el menú de reaccions",
    "React with {emoji}" : "Reacciona amb {emoji}",
    "React with another emoji" : "Reacciona amb un altre emoji",
    "Choose a conversation to forward the selected message." : "Trieu una conversa per reenviar el missatge seleccionat.",
    "Error while forwarding message" : "S'ha produït un error en reenviar el missatge",
    "The message has been forwarded to {selectedConversationName}" : "El missatge s'ha reenviat a {selectedConversationName}",
    "Dismiss" : "Descarta",
    "Go to conversation" : "Vés a la conversa",
    "Detect language" : "Detecta la llengua",
    "The message could not be translated" : "No s'ha pogut traduir el missatge",
    "Translation copied to clipboard" : "La traducció s'ha copiat al porta-retalls",
    "Translation could not be copied" : "No s'ha pogut copiar la traducció",
    "Translate message" : "Tradueix el missatge",
    "Source language to translate from" : "Llengua d'origen per traduir",
    "Translate from" : "Traduir de",
    "Target language to translate into" : "Llengua objectiu a traduir",
    "Translate to" : "Traduir a",
    "Translating" : "S'està traduint",
    "Copy translated text" : "Copia el text traduït",
    "Send now" : "Envia ara",
    "Message read by everyone who shares their reading status" : "Missatge llegit per tothom que comparteix el seu estat de lectura",
    "Message sent" : "Missatge enviat",
    "Sent without notification" : "Enviat sense notificació",
    "Deleting message" : "S'està eliminant el missatge",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "El missatge s'ha suprimit correctament, però s'ha configurat un bot o Matterbridge i és possible que el missatge ja s'hagi distribuït a altres serveis",
    "Message deleted successfully" : "El missatge s'ha suprimit correctament",
    "Message could not be deleted because it is too old" : "No s'ha pogut suprimir el missatge perquè és massa antic",
    "Only normal chat messages can be deleted" : "Només es poden suprimir els missatges de xat normals",
    "An error occurred while deleting the message" : "S'ha produït un error en suprimir el missatge",
    "Your browser does not support playing audio files" : "El vostre navegador no admet la reproducció de fitxers d'àudio",
    "Contact" : "Contacte",
    "{stack} in {board}" : "{stack} a {board}",
    "Deck Card" : "Pila de Targetes",
    "Remove {fileName}" : "Suprimeix {fileName}",
    "Open this location in OpenStreetMap" : "Obriu aquesta ubicació a OpenStreetMap",
    "Sending message" : "S'està enviant el missatge",
    "Failed to send the message. Click to try again" : "No s'ha pogut enviar el missatge. Feu clic per tornar-ho a provar",
    "Not enough free space to upload file" : "No hi ha prou espai lliure per pujar el fitxer",
    "You cannot send messages to this conversation at the moment" : "No pots enviar missatges a aquesta conversa en aquest moment",
    "Could not update the message" : "No s'ha pogut actualitzar el missatge",
    "You voted" : "Has votat",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Esborrany de l'enquesta • Opció %n","Esborrany de l'enquesta • %n opcions"],
    "_%n vote_::_%n votes_" : ["%n vot","%n vots"],
    "Edit poll draft" : "Edita l'esborrany de l'enquesta",
    "Delete poll draft" : "Suprimeix l'esborrany de l'enquesta",
    "Open poll" : "Enquesta oberta",
    "See results" : "Veure resultats",
    "Reactions" : "Reaccions",
    "No permission to post reactions in this conversation" : "No hi ha permís per publicar reaccions en aquesta conversa",
    "and {participant}" : "i {participant}",
    "_and %n other participant_::_and %n other participants_" : ["i %n participant més","i %n participants més"],
    "Show all reactions" : "Mostra totes les reaccions",
    "Add more reactions" : "Afegeix més reaccions",
    "Show or collapse system messages" : "Mostra o replega els missatges del sistema",
    "No messages" : "No hi ha missatges",
    "All messages have expired or have been deleted." : "Tots els missatges han caducat o s'han suprimit.",
    "Unpin" : "No fixis",
    "Cancel search" : "Cancel·la la cerca",
    "Add a phone number" : "Afegeix un número de telèfon",
    "Error: A password is required to create the conversation." : "Error: cal una contrasenya per crear la conversa.",
    "All set, the conversation \"{conversationName}\" was created." : "Tot a punt, s'ha creat la conversa \"{conversationName}\".",
    "Create a new group conversation" : "Crear una conversa de grup nova",
    "Add participants" : "Afegeix participants",
    "Maximum length exceeded ({maxlength} characters)" : "S'ha superat la longitud màxima ({maxlength} caràcters)",
    "Conversation visibility" : "Visibilitat de la conversa",
    "Allow guests to join via link" : "Permet als convidats unir-se mitjançant un enllaç",
    "Enter password" : "Introduïu la contrasenya",
    "This conversation has been locked" : "Aquesta conversa s'ha bloquejat",
    "No permission to post messages in this conversation" : "No hi ha permís per publicar missatges en aquesta conversa",
    "Joining conversation …" : "S'està unint a la conversa …",
    "Write a message without notification" : "Escriu un missatge sense notificació",
    "Send message silently" : "Enviar missatge en silenci",
    "Send message" : "Envia un missatge",
    "Send without notification" : "Envia sense notificació",
    "The participant will not be notified about new messages" : "El participant no rebrà notificacions sobre missatges nous",
    "Participants will not be notified about new messages" : "Els participants no rebran notificacions dels missatges nous",
    "The message could not be edited" : "No s'ha pogut editar el missatge",
    "File to share" : "Fitxer a compartir",
    "File upload is not available in this conversation" : "La càrrega de fitxers no està disponible en aquesta conversa",
    "Add emoji" : "Afegeix emoji",
    "Adding a mention will only notify users who did not read the message." : "Afegir una menció només notificarà als usuaris que no hagin llegit el missatge.",
    "Send later" : "Envia més tard",
    "Cancel editing" : "Cancel·la l'edició",
    "{user} is out of office and might not respond." : "{user} està fora de l'oficina i és possible que no respongui.",
    "Absence period: {startDate} - {endDate}" : "Període d'absència: {startDate} - {endDate}",
    "Replacement:" : "Substitució:",
    "Share from {nextcloud}" : "Comparteix des de {nextcloud}",
    "Share from Files" : "Comparteix des de Fitxers",
    "Share files to the conversation" : "Compartir fitxers a la conversa",
    "Upload from device" : "Pujada des del dispositiu",
    "Create new poll" : "Crea una nova enquesta",
    "Smart picker" : "Selector intel·ligent",
    "Record voice message" : "Grava un missatge de veu",
    "End recording and send" : "Finalitzar la gravació i enviar",
    "Dismiss recording" : "Descarta la gravació",
    "Access to the microphone was denied" : "S'ha denegat l'accés al micròfon",
    "Microphone either not available or disabled in settings" : "El micròfon no està disponible o està desactivat als paràmetres",
    "Error while recording audio" : "S'ha produït un error en gravar l'àudio",
    "Generating summary of unread messages …" : "S'està generant un resum dels missatges no llegits …",
    "Summary is AI generated and might contain mistakes" : "El resum es genera amb IA i pot contenir errors",
    "Error occurred during a summary generation" : "S'ha produït un error durant la generació d'un resum",
    "New file" : "Nou fitxer",
    "Blank" : "En blanc",
    "Error while creating file" : "Error en crear el fitxer",
    "Create and share a new file" : "Creació i compartició d'un fitxer nou",
    "Name of the new file" : "Nom del nou fitxer",
    "Create file" : "Crea el fitxer",
    "Someone is typing …" : "Algú està escrivint …",
    "{user1} is typing …" : "{user1} està escrivint …",
    "{user1} and {user2} are typing …" : "{user1} i {user2} estan escrivint …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} i {user3} estan escrivint …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} i %n més estan escrivint …","{user1}, {user2}, {user3} i %n més estan escrivint …"],
    "Add more files" : "Afegeix més fitxers",
    "Send" : "Envia",
    "In this conversation <strong>{user}</strong> can:" : "En aquesta conversa <strong>{user}</strong> pot:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Edita els permisos per defecte per als participants a <strong>{conversationName}</strong>",
    "Start a call" : "Inicia una trucada",
    "Skip the lobby" : "Omet el vestíbul",
    "Can post messages and reactions" : "Pot publicar missatges i reaccions",
    "Enable the microphone" : "Habilitar el micròfon",
    "Enable the camera" : "Habilitar la càmera",
    "Share the screen" : "Compartir la pantalla",
    "Update permissions" : "Actualitzar els permisos",
    "Updating permissions" : "S'estan actualitzant els permisos",
    "No poll drafts" : "No hi ha esborranys d'enquesta",
    "There is no poll drafts yet saved for this conversation" : "Encara no hi ha cap esborrany d'enquesta desat per a aquesta conversa",
    "Create poll in {name}" : "Crea una enquesta a {name}",
    "Create poll" : "Crea enquesta",
    "Error while importing poll" : "S'ha produït un error en importar l'enquesta",
    "Question" : "Qüestió",
    "Ask a question" : "Fer una pregunta",
    "Import draft from file" : "Importa l'esborrany del fitxer",
    "Answers" : "Respostes",
    "Answer {option}" : "Resposta {option}",
    "Delete poll option" : "Suprimeix l'opció de l'enquesta",
    "Add answer" : "Afegeix la resposta",
    "Settings" : "Paràmetres",
    "Anonymous poll" : "Enquesta anònima",
    "Multiple answers" : "Respostes múltiples",
    "Save as draft" : "Desa com a esborrany",
    "Export draft to file" : "Exporta l'esborrany al fitxer",
    "You voted for this option" : "Heu votat aquesta opció",
    "End poll" : "Finalitza l'enquesta",
    "Change your vote" : "Canvia el teu vot",
    "Results" : "Resultats",
    "Voted participants" : "Participants votats",
    "Send a message to \"{roomName}\"" : "Envia un missatge a \"{roomName}\"",
    "Hide list of participants" : "Amaga la llista de participants",
    "Show list of participants" : "Mostra la llista de participants",
    "Assistance requested in {roomName}" : "Ajuda sol·licitada a {roomName}",
    "The message was sent to \"{roomName}\"" : "El missatge s'ha enviat a \"{roomName}\"",
    "Dismiss request for assistance" : "Descarta la sol·licitud d'assistència",
    "Send message to room" : "Envia missatge a l'habitació",
    "Back to main room" : "Tornada a la sala principal",
    "Back to your room" : "Torna a la teva habitació",
    "Message all rooms" : "Envia un missatge a totes les habitacions",
    "Start session" : "Inicia sessió",
    "Start a call before you start a breakout room session" : "Inicieu una trucada abans d'iniciar una sessió de sala de treball",
    "Stop session" : "Atura la sessió",
    "The message was sent to all breakout rooms" : "El missatge s'ha enviat a totes les sales de treball",
    "Send a message to all breakout rooms" : "Envia un missatge a totes les sales de treball",
    "Breakout rooms are not started" : "Les sales de treball no s'inicien",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Les trucades sense backend d'alt rendiment poden causar problemes de connectivitat i una càrrega elevada als dispositius. {linkstart}Més informació{linkend}",
    "Talk setup incomplete" : "Configuració de la conversa incompleta",
    "Disable lobby" : "Inhabilita el vestíbul",
    "Settings for participant \"{user}\"" : "Paràmetres per al participant \"{user}\"",
    "Participant \"{user}\"" : "Participant \"{user}\"",
    "moderator" : "moderador",
    "bot" : "autòmata",
    "guest" : "convidat",
    "Ringing …" : "Sonant …",
    "Call rejected" : "Trucada rebutjada",
    "{time} talking …" : "{time} parlant …",
    "{time} talking time" : "{time} temps de conversa",
    "Raised their hand" : "Van aixecar la mà",
    "Joined with video" : "S'ha unit amb vídeo",
    "Joined via phone" : "S'ha unit per telèfon",
    "Joined with audio" : "S'ha unit amb àudio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "El text ha de tenir una longitud inferior o igual a {maxLength} caràcters. El vostre text actual té {charactersCount} caràcters.",
    "Remove group and members" : "Suprimir el grup i els membres",
    "Remove team and members" : "Suprimeix l'equip i els membres",
    "Remove participant" : "Suprimir el participant",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Segur que voleu eliminar el grup \"{displayName}\" i els seus membres d'aquesta conversa?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Realment voleu eliminar l'equip \"{displayName}\" i els seus membres d'aquesta conversa?",
    "Do you really want to remove {displayName} from this conversation?" : "Segur que voleu eliminar {displayName} d'aquesta conversa?",
    "Notification was sent to {displayName}" : "La notificació s'ha enviat a {displayName}",
    "Could not send notification to {displayName}" : "No s'ha pogut enviar la notificació a {displayName}",
    "Permissions granted to {displayName}" : "Permisos concedits a {displayName}",
    "Could not modify permissions for {displayName}" : "No s'han pogut modificar els permisos de {displayName}",
    "Permissions removed for {displayName}" : "S'han eliminat els permisos per a {displayName}",
    "Permissions set to default for {displayName}" : "Permisos establerts per defecte per a {displayName}",
    "Phone number could not be hung up" : "No s'ha pogut penjar el número de telèfon",
    "Phone number could not be put on hold" : "El número de telèfon no s'ha pogut posar en espera",
    "Phone number could not be muted" : "No s'ha pogut silenciar el número de telèfon",
    "Phone number could not be unmuted" : "No s'ha pogut activar el so del número de telèfon",
    "DTMF message could not be sent" : "No s'ha pogut enviar el missatge DTMF",
    "Phone number copied to clipboard" : "El número de telèfon s'ha copiat al porta-retalls",
    "Phone number could not be copied" : "No s'ha pogut copiar el número de telèfon",
    "in the lobby" : "al vestíbul",
    "Dial out phone" : "Marqueu el telèfon",
    "Hang up phone" : "Penja el telèfon",
    "Move back to lobby" : "Torneu al vestíbul",
    "Move to conversation" : "Passa a la conversa",
    "Dial-in PIN" : "PIN de marcatge",
    "Demote from moderator" : "Retenció del moderador",
    "Promote to moderator" : "Promociona al moderador",
    "Resend invitation" : "Torna a enviar el correu d'invitació",
    "Send call notification" : "Envia una notificació de trucada",
    "Dial out phone number" : "Marqueu el número de telèfon",
    "Resume call for phone number" : "Reprèn la trucada pel número de telèfon",
    "Put phone number on hold" : "Posa el número de telèfon en espera",
    "Unmute phone number" : "Activa el so del número de telèfon",
    "Mute phone number" : "Silencia el número de telèfon",
    "Copy phone number" : "Copia el número de telèfon",
    "Reset custom permissions" : "Restableix els permisos personalitzats",
    "Grant all permissions" : "Concediu tots els permisos",
    "Remove all permissions" : "Suprimir tots els permisos",
    "Also ban from this conversation" : "També prohibeix aquesta conversa",
    "Internal note (reason to ban)" : "Nota interna (motiu de la prohibició)",
    "Remove" : "Suprimir",
    "Permissions modified for {displayName}" : "Permisos modificats per a {displayName}",
    "Add users, groups or teams" : "Afegiu usuaris, grups o equips",
    "Add users or groups" : "Afegeix usuaris o grups",
    "Add users or teams" : "Afegiu usuaris o equips",
    "Add users" : "Afegeix usuaris",
    "Add groups or teams" : "Afegiu grups o equips",
    "Add groups" : "Afegeix grups",
    "Add teams" : "Afegeix equips",
    "Add other sources" : "Afegeix altres fonts",
    "Add emails" : "Afegeix correus electrònics",
    "Integrations" : "Integracions",
    "Add federated users" : "Afegeix usuaris federats",
    "Searching …" : "Cercant …",
    "Search for more users" : "Cercar més usuaris",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Podeu cercar o afegir participants mitjançant el nom, el correu electrònic o l'identificador de núvol federat",
    "Search or add participants" : "Cerca o afegeix participants",
    "Invitation was sent to {actorId}" : "S'ha enviat la invitació a {actorId}",
    "An error occurred while adding the participants" : "S'ha produït un error en afegir els participants",
    "Participants" : "Participants",
    "Participants ({count})" : "Participants ({count})",
    "Open chat" : "Xat obert",
    "You have new unread messages in the chat." : "Tens missatges nous sense llegir al xat.",
    "You have been mentioned in the chat." : "Has estat esmentat al xat.",
    "Search messages" : "Cerca missatges",
    "Chat" : "Xat",
    "Details" : "Detalls",
    "Shared items" : "Elements compartits",
    "Search in {name}" : "Cerca a {name}",
    "Search messages …" : "Cerca missatges …",
    "Search options" : "Opcions de cerca",
    "From User" : "De l'usuari",
    "Since" : "Des de",
    "Until" : "Fins",
    "No results found" : "No s'han trobat resultats",
    "Load more results" : "Carregar més resultats",
    "Projects" : "Projectes",
    "No shared items" : "No hi ha elements compartits",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Enllaça a una conversa",
    "No open conversations found" : "No s'han trobat converses obertes",
    "Either there are no open conversations or you joined all of them." : "O no hi ha converses obertes o t'has unit a totes.",
    "Check spelling or use complete words." : "Revisa l'ortografia o utilitza paraules completes.",
    "Search conversations or users" : "Cercar converses o usuaris",
    "Select conversation" : "Seleccioneu una conversa",
    "Number length is not valid" : "La longitud del número no és vàlida",
    "Region code is not valid" : "El codi de regió no és vàlid",
    "Number length is too short" : "La longitud del número és massa curta",
    "Number length is too long" : "La longitud del número és massa llarga",
    "Number is not valid" : "El número no és vàlid",
    "Phone numbers" : "Números de telèfon",
    "Display name: {name}" : "Nom de visualització: {name}",
    "Edit display name" : "Edició del nom a mostrar",
    "Save name" : "Desar el nom",
    "Error while setting personal setting" : "S'ha produït un error en configurar la configuració personal",
    "Error while saving sounds setting" : "S'ha produït un error en desar els paràmetres dels sons",
    "Play sounds when participants join or leave a call" : "Reprodueix sons quan els participants s'uneixen o surten d'una trucada",
    "Notification settings" : "Paràmetres de les notificacions",
    "Default language" : "Llengua per defecte",
    "Select location for attachments" : "Seleccioneu la ubicació per als fitxers adjunts",
    "Error while setting attachment folder" : "S'ha produït un error en establir la carpeta de fitxers adjunts",
    "Error while setting read status privacy" : "S'ha produït un error en configurar la privadesa de l'estat de lectura",
    "Error while setting typing status privacy" : "S'ha produït un error en configurar la privadesa de l'estat d'escriure",
    "Error while setting default media state" : "S'ha produït un error en establir l'estat predeterminat dels mitjans",
    "Privacy" : "Privadesa",
    "Attachments folder" : "Carpeta fitxers adjunts",
    "Toggle full screen" : "Commuta la pantalla completa",
    "Search" : "Cerca",
    "Focus the chat input" : "Posar focus a l'entrada del xat",
    "Unfocus the chat input to use shortcuts" : "Treure focus de l'entrada del xat per utilitzar dreceres",
    "Edit your last message" : "Editeu el vostre darrer missatge",
    "Shortcuts while in a call" : "Dreceres mentre es troba en una trucada",
    "Camera on and off" : "Càmera i desactivada",
    "Microphone on and off" : "El micròfon activat i desactivat",
    "Raise or lower hand" : "Aixecar o baixar la mà",
    "Push to talk or push to mute" : "Premeu per parlar o premeu per silenciar",
    "Zoom-in / zoom-out a screen share" : "Apropar/reduir una pantalla compartida",
    "Mouse wheel" : "Roda del ratolí",
    "Start call silently" : "Inicia la trucada en silenci",
    "Start call" : "Inicia trucada",
    "End call" : "Finalitzar la trucada",
    "This call has just ended" : "Aquesta trucada acaba de finalitzar",
    "You will be able to join the call only after a moderator starts it." : "Només podreu unir-vos a la trucada un cop s'inicii per un moderador.",
    "End call for everyone" : "Finalitzar la trucada per a tothom",
    "Starting the recording" : "Iniciant la gravació",
    "Recording" : "Enregistrament",
    "The call has been running for one hour." : "La trucada porta una hora en marxa.",
    "Cancel recording start" : "Cancel·la l'inici de la gravació",
    "Stop recording" : "Aturar l'enregistrament",
    "Raise hand" : "Aixeca la mà",
    "Raise hand (R)" : "Aixeca la mà (R)",
    "Lower hand" : "Baixa mà",
    "Lower hand (R)" : "Baixa mà (R)",
    "Send a reaction" : "Envia una reacció",
    "React with {reaction}" : "Reacciona amb {reaction}",
    "All tasks done!" : "Totes les tasques fetes!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} de %n tasca","{done} de %n tasques"],
    "_%n participant in call_::_%n participants in call_" : ["%n participant a la trucada","%n participants a la trucada"],
    "You are not allowed to enable screensharing" : "No teniu permís per activar l'ús compartit de pantalla",
    "No screensharing" : "Deixar de compartir pantalla",
    "Screensharing options" : "Preferències de compartició de pantalla",
    "Enable screensharing" : "Habilitar la compartició de pantalla",
    "Bad sent video and screen quality." : "Mala qualitat de vídeo i pantalla enviada.",
    "Bad sent screen quality." : "Mala qualitat de pantalla enviada.",
    "Bad sent video quality." : "Mala qualitat de vídeo enviada.",
    "Bad sent audio, video and screen quality." : "Mala qualitat d'àudio, vídeo i pantalla enviada.",
    "Bad sent audio and screen quality." : "Mala qualitat d'àudio i pantalla enviada.",
    "Bad sent audio and video quality." : "Mala qualitat d'àudio i vídeo enviat.",
    "Bad sent audio quality." : "Mala qualitat d'àudio enviada.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "La teva connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no puguin veure la teva pantalla. Per millorar la situació, proveu de inhabilitar el desenfocament de fons o el vostre vídeo mentre feu una compartició de pantalla.",
    "Disable background blur" : "Inhabilitar el desenfocament de fons",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "La teva connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no puguin veure la teva pantalla. Per millorar la situació, proveu de inhabilitar el vostre vídeo mentre feu una pantalla compartida.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "És possible que la connexió a Internet o l'ordinador estiguin ocupats i és possible que altres participants no puguin veure la vostra pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "La connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no us puguin veure.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "La teva connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no puguin entendre't ni veure't. Per millorar la situació, proveu de inhabilitar el desenfocament de fons o el vostre vídeo mentre feu una pantalla compartida.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "La connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no puguin entendre't i veure't. Per millorar la situació, proveu de inhabilitar el vídeo mentre es fa una compartició de pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "La vostra connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no us puguin entendre ni veure la vostra pantalla. Per millorar la situació, prova de inhabilitar la teva pantalla compartida.",
    "Disable screenshare" : "Inhabilitar la compartició de pantalla",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "La teva connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no puguin entendre't ni veure't. Per millorar la situació, prova de inhabilitar el desenfocament de fons o el teu vídeo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "La connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no puguin entendre't i veure't. Per millorar la situació, proveu de inhabilitar el vostre vídeo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "La connexió a Internet o l'ordinador estan ocupats i és possible que altres participants no us puguin entendre.",
    "Screen sharing is not supported by your browser." : "El navegador no admet l'ús compartit de pantalla.",
    "Screen sharing requires the page to be loaded through HTTPS." : "L'ús compartit de pantalla requereix que la pàgina es carregui mitjançant HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "L'ús compartit de la pantalla requereix que la pàgina es carregui a través d'HTTPS.",
    "An error occurred while starting screensharing." : "S'ha produït un error en iniciar l'ús compartit de la pantalla.",
    "Show your screen" : "Mostra la teva pantalla",
    "Stop screensharing" : "Deixar de compartir",
    "Mute others" : "Silenciar els altres",
    "Start recording" : "Inici de l'enregistrament",
    "Set up breakout rooms" : "Configureu sales de treball",
    "Download attendance list" : "Descarrega la llista d'assistència",
    "Open Calendar" : "Obriu el calendari",
    "Remove participant {name}" : "Suprimir el participant {name}",
    "Keep" : "Mantén",
    "Open dialpad" : "Obre el teclat",
    "Select a region" : "Selecciona una regió",
    "Search …" : "Cerca …",
    "Message without mention" : "Missatge sense menció",
    "Mention myself" : "Menció a mi mateix",
    "Mention everyone" : "Esmenta a tothom",
    "Select a conversation" : "Seleccioneu una conversa",
    "Select a mode" : "Seleccioneu un mode",
    "You do not have permissions to access this conversation." : "No tens permís per accedir a aquesta conversa.",
    "Join a different conversation or start a new one." : "Uneix-te a una conversa diferent o inicia-ne una de nova.",
    "The conversation does not exist" : "La conversa no existeix",
    "Join a conversation or start a new one!" : "Uneix-vos a una conversa o inicia'n una de nova!",
    "Creating and joining a conversation with \"{userid}\"" : "Crear i unir-se a una conversa amb \"{userid}\"",
    "Join a conversation or start a new one" : "Uniu-vos a una conversa o inicieu-ne una de nova",
    "Error while joining the conversation" : "S'ha produït un error en unir-se a la conversa",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Usuari Nextcloud",
    "User password" : "Contrasenya d'usuari",
    "Talk conversation" : "Conversa de Talk",
    "Skip TLS verification" : "Skip TLS verification",
    "Matrix server URL" : "URL del servidor Matrix",
    "User" : "Usuari",
    "Matrix channel" : "Canal de Matrix",
    "Mattermost server URL" : "URL del servidor de Mattermost",
    "Mattermost user" : "Usuari Mattermost",
    "Team name" : "Nom de l'equip",
    "Channel name" : "Nom del canal",
    "Rocket.Chat server URL" : "URL del servidor Rocket.Chat",
    "User name or email address" : "Nom d'usuari o adreça de correu electrònic",
    "Rocket.Chat channel" : "Canal Rocket.Chat",
    "Zulip server URL" : "URL del servidor Zulip",
    "Bot user name" : "Nom d'usuari del bot",
    "Bot API key" : "Clau de l'API del bot",
    "Zulip channel" : "Canal Zulip",
    "API token" : "Codi de l'API",
    "Slack channel" : "Canal slack",
    "Server ID or name" : "ID o nom del servidor",
    "Channel ID (prefixed with \"ID:\") or name" : "Identificador del canal (prefixat amb \"ID:\") o nom",
    "Channel" : "Canal",
    "Login" : "Inici de sessió",
    "Chat ID" : "ID de xat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "Areça URL del servidor IRC (p. ex., chat.freenode.net:6667)",
    "Nickname" : "Sobrenom",
    "Connection password" : "Contrasenya de connexió",
    "IRC channel" : "Canal IRC",
    "Channel password" : "Contrasenya del canal",
    "NickServ nickname" : "NickServ nickname",
    "NickServ password" : "NickServ password",
    "Use TLS" : "Fer servir TLS",
    "Use SASL" : "Fer servir SASL",
    "Tenant ID" : "ID de l'inquilí",
    "Client ID" : "ID de Client",
    "Team ID" : "ID de l'equip",
    "Thread ID" : "ID de fil",
    "XMPP/Jabber server URL" : "URL del servidor XMPP/Jabber",
    "MUC server URL" : "URL del servidor MUC",
    "Jabber ID" : "ID del Jabber",
    "Media" : "Multimèdia",
    "Polls" : "Enquestes",
    "Deck cards" : "Pila de targetes",
    "Voice messages" : "Missatges de veu",
    "Locations" : "Ubicacions",
    "Call recordings" : "Enregistraments de trucades",
    "Audio" : "Àudio",
    "Show all media" : "Mostra tots els mitjans",
    "Show all files" : "Mostra tots els fitxers",
    "Show all polls" : "Mostra totes les enquestes",
    "Show all deck cards" : "Mostra totes les cartes de baralla",
    "Show all voice messages" : "Mostra tots els missatges de veu",
    "Show all locations" : "Mostra totes les ubicacions",
    "Show all call recordings" : "Mostra tots els enregistraments de trucades",
    "Show all audio" : "Mostra tot l'àudio",
    "Show all other" : "Mostra tots els altres",
    "Group" : "Grup",
    "Team" : "Equip",
    "You reconnected to the call" : "T'has tornat a connectar a la trucada",
    "{actor} reconnected to the call" : "{actor} s'ha tornat a connectar a la trucada",
    "You added {user0} and {user1}" : "Heu afegit {user0} i {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Heu afegit {user0}, {user1} i %n participant més","Heu afegit {user0}, {user1} i %n participants més"],
    "An administrator added you and {user0}" : "Un administrador t'ha afegit a tu i a {user0}",
    "{actor} added you and {user0}" : "{actor} t'ha afegit a tu i a {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Un administrador t'ha afegit a tu, {user0} i %n participant més","Un administrador t'ha afegit a tu, {user0} i %n participants més"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} t'ha afegit a tu, {user0} i %n participant més","{actor} t'ha afegit a tu, {user0} i %n participants més"],
    "An administrator added {user0} and {user1}" : "Un administrador ha afegit {user0} i {user1}",
    "{actor} added {user0} and {user1}" : "{actor} ha afegit {user0} i {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Un administrador ha afegit {user0}, {user1} i %n participant més","Un administrador ha afegit {user0}, {user1} i %n participants més"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} ha afegit {user0}, {user1} i %n participant més","{actor} ha afegit {user0}, {user1} i %n participants més"],
    "You removed {user0} and {user1}" : "Has eliminat {user0} i {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Has eliminat {user0}, {user1} i %n participants més","Has eliminat {user0}, {user1} i %n participants més"],
    "An administrator removed you and {user0}" : "Un administrador t'ha suprimit a tu i a {user0}",
    "{actor} removed you and {user0}" : "{actor} us ha eliminat a vosaltres i a {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Un administrador us ha eliminat a vosaltres, a {user0} i a %n participants més","Un administrador us ha eliminat a vosaltres, {user0} i %n participants més"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} us ha eliminat a vosaltres, {user0} i %n participants més","{actor} us ha eliminat a vosaltres, {user0} i %n participants més"],
    "An administrator removed {user0} and {user1}" : "Un administrador ha eliminat {user0} i {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} ha eliminat {user0} i {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Un administrador ha eliminat {user0}, {user1} i %n participants més","Un administrador ha eliminat {user0}, {user1} i %n participants més"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} ha eliminat {user0}, {user1} i %n participants més","{actor} ha eliminat {user0}, {user1} i %n participants més"],
    "You and {user0} joined the call" : "Tu i {user0} us heu unit a la trucada",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Tu, {user0} i %n participant més us heu unit a la trucada","Tu, {user0} i %n participants més us heu unit a la trucada"],
    "{user0} and {user1} joined the call" : "{user0} i {user1} s'han unit a la trucada",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} i %n participant més s'han unit a la trucada","{user0}, {user1} i %n participants més s'han unit a la trucada"],
    "You and {user0} left the call" : "Tu i {user0} heu deixat la trucada",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Tu, {user0} i %n participant més van deixar la trucada","Tu, {user0} i %n participants més van deixar la trucada"],
    "{user0} and {user1} left the call" : "{user0} i {user1} van deixar la trucada",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} i %n participant més van abandonar la trucada","{user0}, {user1} i %n participants més van abandonar la trucada"],
    "You promoted {user0} and {user1} to moderators" : "Has promocionat {user0} i {user1} a moderadors",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Has promocionat {user0}, {user1} i %n participant més a moderadors","Has promocionat {user0}, {user1} i %n participants més a moderadors"],
    "An administrator promoted you and {user0} to moderators" : "Un administrador us ha promocionat a ru i a {user0} a moderadors",
    "{actor} promoted you and {user0} to moderators" : "{actor} us ha promocionat i a {user0} a moderadors",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Un administrador us ha promocionat a ru, {user0} i %n participant més a moderadors","Un administrador us ha promocionat a tu, {user0} i %n participants més a moderadors"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} us ha promocionat a tu, {user0} i %n participant més a moderadors","{actor} us ha promocionat a tu, {user0} i %n participants més a moderadors"],
    "An administrator promoted {user0} and {user1} to moderators" : "Un administrador ha promocionat {user0} i {user1} a moderadors",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} ha promocionat {user0} i {user1} a moderadors",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Un administrador va promocionar {user0}, {user1} i %n participant més a moderadors","Un administrador va promocionar {user0}, {user1} i %n participants més a moderadors"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} ha promocionat {user0}, {user1} i %n participant més a moderadors","{actor} ha promocionat {user0}, {user1} i %n participants més a moderadors"],
    "You demoted {user0} and {user1} from moderators" : "Has degradat {user0} i {user1} dels moderadors",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Has degradat {user0}, {user1} i %n participant més dels moderadors","Has degradat {user0}, {user1} i %n participants més dels moderadors"],
    "An administrator demoted you and {user0} from moderators" : "Un administrador us ha degradat a tu i a {user0} dels moderadors",
    "{actor} demoted you and {user0} from moderators" : "{actor} us ha degradat a tu i a {user0} dels moderadors",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Un administrador us ha degradat a tu, {user0} i %n participant més dels moderadors","Un administrador us ha degradat a tu, {user0} i %n participants més dels moderadors"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} us ha degradat a tu, {user0} i %n participant més dels moderadors","{actor} us ha degradat a tu, {user0} i %n participants més dels moderadors"],
    "An administrator demoted {user0} and {user1} from moderators" : "Un administrador ha degradat {user0} i {user1} dels moderadors",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} ha degradat {user0} i {user1} dels moderadors",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Un administrador ha degradat {user0}, {user1} i %n participant més dels moderadors","Un administrador ha degradat {user0}, {user1} i %n participants més dels moderadors"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} ha degradat {user0}, {user1} i %n participant més dels moderadors","{actor} ha degradat {user0}, {user1} i %n participants més dels moderadors"],
    "You: {lastMessage}" : "Vostè: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(editat per tu)",
    "(edited by a deleted user)" : "(editat per un usuari eliminat)",
    "(edited by {moderator})" : "(editat per {moderator})",
    "The recording failed. Please contact your administrator." : "La gravació ha fallat. Poseu-vos en contacte amb el vostre administrador.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Esteu intentant unir-vos a una conversa mentre teniu una sessió activa en una altra finestra o dispositiu. Això actualment no és compatible amb Nextcloud Talk. Què voleu fer?",
    "Leave this page" : "Surt d'aquesta pàgina",
    "Join here" : "Unir-se aquí",
    "Deck card has been posted to {conversation}" : "La pila de targetes s'ha publicat a {conversation}",
    "An error occurred while posting deck card to conversation" : "S'ha produït un error en publicar la pila de targetes a la conversa",
    "Post to a conversation" : "Publica en una conversa",
    "Post to conversation" : "Publica a la conversa",
    "Location has been posted to {conversation}" : "La ubicació s'ha publicat a {conversation}",
    "An error occurred while posting location to conversation" : "S'ha produït un error en publicar la ubicació a la conversa",
    "Share to a conversation" : "Comparteix en una conversa",
    "Share to conversation" : "Comparteix a la conversa",
    "In conversation" : "En conversa",
    "Search in conversation: {conversation}" : "Cerca a la conversa: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Les vostres sol·licituds estan limitades en aquest moment a causa de la protecció de força bruta",
    "Error while clearing conversation history" : "S'ha produït un error en esborrar l'historial de converses",
    "Error occurred while allowing guests" : "S'ha produït un error en permetre els convidats",
    "Error occurred while disallowing guests" : "S'ha produït un error en desactivar convidats",
    "Error occurred when restricting the conversation to moderator" : "S'ha produït un error en restringir la conversa al moderador",
    "Error occurred when opening the conversation to everyone" : "S'ha produït un error en obrir la conversa a tothom",
    "Conversation password has been saved" : "La contrasenya de la conversa s'ha desat",
    "Conversation password has been removed" : "La contrasenya de la conversa s'ha eliminat",
    "Error occurred while saving conversation password" : "S'ha produït un error en desar la contrasenya de la conversa",
    "Call recording is starting." : "S'està començant la gravació de trucades.",
    "Call recording stopped while starting." : "La gravació de trucades s'ha aturat mentre començava.",
    "Call recording stopped. You will be notified once the recording is available." : "S'ha aturat la gravació de trucades. Se us notificarà quan la gravació estigui disponible.",
    "Conversation picture set" : "Conjunt d'imatges de conversa",
    "Conversation picture deleted" : "S'ha suprimit la imatge de la conversa",
    "Could not delete the conversation picture" : "No s'ha pogut suprimir la imatge de la conversa",
    "Could not post message: {errorMessage}" : "No s'ha pogut publicar el missatge: {errorMessage}",
    "Participant is banned successfully" : "El participant està prohibit correctament",
    "Error while banning the participant" : "S'ha produït un error en prohibir el participant",
    "An error occurred while fetching the participants" : "S'ha produït un error en recuperar els participants",
    "Could not send invitation to {actorId}" : "No s'ha pogut enviar la invitació a {actorId}",
    "Invitations sent" : "Invitacions enviades",
    "Error occurred when sending invitations" : "S'ha produït un error en enviar les invitacions",
    "Failed to join the conversation." : "No s'ha pogut unir a la conversa.",
    "An error occurred while creating breakout rooms" : "S'ha produït un error en crear les sales de treball",
    "An error occurred while re-ordering the attendees" : "S'ha produït un error en tornar a ordenar els assistents",
    "An error occurred while deleting breakout rooms" : "S'ha produït un error en suprimir les sales de treball",
    "An error occurred while starting breakout rooms" : "S'ha produït un error en iniciar les sales de treball",
    "An error occurred while stopping breakout rooms" : "S'ha produït un error en aturar les sales de treball",
    "An error occurred while sending a message to the breakout rooms" : "S'ha produït un error en enviar un missatge a les sales de treball",
    "An error occurred while requesting assistance" : "S'ha produït un error en sol·licitar ajuda",
    "An error occurred while resetting the request for assistance" : "S'ha produït un error en restablir la sol·licitud d'assistència",
    "An error occurred while joining breakout room" : "S'ha produït un error en unir-se a la sala de grups",
    "An error occurred while accepting an invitation" : "S'ha produït un error en acceptar una invitació",
    "An error occurred while rejecting an invitation" : "S'ha produït un error en rebutjar una invitació",
    "{guest} (guest)" : "{guest} (convidat)",
    "Poll draft has been saved" : "S'ha desat l'esborrany de l'enquesta",
    "An error occurred while saving the draft" : "S'ha produït un error en desar l'esborrany",
    "An error occurred while submitting your vote" : "S'ha produït un error en enviar el vostre vot",
    "An error occurred while ending the poll" : "S'ha produït un error en finalitzar l'enquesta",
    "An error occurred while deleting the poll draft" : "S'ha produït un error en suprimir l'esborrany de l'enquesta",
    "Poll \"{name}\" was created by {user}. Click to vote" : "L'enquesta \"{name}\" l'ha creat {user}. Feu clic per votar",
    "Failed to add reaction" : "No s'ha pogut afegir la reacció",
    "Failed to remove reaction" : "No s'ha pogut suprimir la reacció",
    "Error while uploading file \"{fileName}\"" : "Error en carregar el fitxer \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "No hi ha prou espai lliure per pujar el fitxer \"{fileName}\"",
    "You are not allowed to share files" : "No teniu permís per compartir fitxers",
    "Error while sharing file" : "Error en compartir el fitxer",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "El navegador que utilitzeu no és totalment compatible amb Nextcloud Talk. Feu servir la darrera versió de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
    "_%n day_::_%n days_" : ["%n dia","%n dies"],
    "_%n week_::_%n weeks_" : ["%n setmana","%n setmanes"],
    "_In %n hour_::_In %n hours_" : ["D'aquí a %n hora","d'aquí %n hores"],
    "_%n minute _::_%n minutes_" : ["d'aquí a %n minut","%n minuts"],
    "In {hours} and {minutes}" : "A {hours} i {minutes}",
    "_In %n minute_::_In %n minutes_" : ["D'aquí a %n minut","d'aquí %n minuts"],
    "Later today – {timeLocale}" : "Avui més tard: {timeLocale}",
    "Tomorrow – {timeLocale}" : "Demà: {timeLocale}",
    "This weekend – {timeLocale}" : "Aquest cap de setmana: {timeLocale}",
    "Next week – {timeLocale}" : "La setmana següent: {timeLocale}",
    "Message link copied to clipboard" : "S'ha copiat l'enllaç del missatge al porta-retalls",
    "Conversation link copied to clipboard" : "L'enllaç de la conversa s'ha copiat al porta-retalls",
    "The link could not be copied" : "No s'ha pogut copiar l'enllaç",
    "Error while parsing a PROPFIND error" : "S'ha produït un error en analitzar un error PROPFIND",
    "Sending signaling message has failed" : "No s'ha pogut enviar el missatge de senyalització",
    "Lost connection to signaling server. Trying to reconnect." : "S'ha perdut la connexió al servidor de senyalització. S'està intentant tornar a connectar.",
    "Lost connection to signaling server." : "S'ha perdut la connexió amb el servidor de senyalització.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "El servidor de senyalització configurat s'ha d'actualitzar perquè sigui compatible amb aquesta versió de Converses. Si us plau, poseu-vos en contacte amb la vostre administració.",
    "Please restart the app." : "Si us plau, reinicieu l'aplicació.",
    "Please reload the page." : "Torneu a carregar la pàgina.",
    "Please try to restart the app." : "Si us plau, prova de reiniciar l'aplicació.",
    "Please try to reload the page." : "Si us plau, prova de tornar a carregar la pàgina.",
    "Do not disturb" : "No molesteu",
    "Away" : "Absent",
    "Microphone {number}" : "Micròfon {number}",
    "Camera {number}" : "Càmera {number}",
    "Speaker {number}" : "Altaveu {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Sembla que esteu parlant mentre esteu silenciat/da, si us plau, deixeu de silenciar-vos perquè altres persones us puguin sentir",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "No s'ha pogut establir una connexió amb almenys un participant. Pot ser que calgui un servidor TURN per a l'escenari. Demaneu a l'administrador que en configure un després segons {linkstart}aquesta documentació{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Això ja porta massa estona. Ja s'han acceptat (o rebutjat) els permisos multimèdia necessaris al vostre navegador/sistema? Si és així llavors reinicieu el navegador web, perquè estan fallant l'àudio i el vídeo",
    "Access to microphone & camera is only possible with HTTPS" : "L'accés al micròfon i a la càmera només és possible amb HTTPS",
    "Please move your setup to HTTPS" : "Heu de canviar la vostra configuració a HTTPS",
    "Access to microphone & camera was denied" : "S'ha denegat l'accés al micròfon i a la càmera",
    "WebRTC is not supported in your browser" : "WebRTC no és compatible amb el vostre navegador",
    "Please use a different browser like Firefox or Chrome" : "Si us plau, utilitzeu un navegador diferent, com Firefox o Chrome",
    "Error while accessing microphone & camera" : "S'ha produït un error en accedir al micròfon i a la càmera",
    "%s Talk on your mobile devices" : "%s Talk als vostres dispositius mòbils",
    "Join conversations at any time, anywhere, on any device." : "Uneix-te a les converses en qualsevol moment, en qualsevol lloc, i en qualsevol dispositiu.",
    "Android app" : "Aplicació d'Android",
    "iOS app" : "aplicació d'iOS",
    "__language_name__" : "__language_name__",
    "Webhook Demo" : "Demostració de Webhook",
    "Call summary (%s)" : "Resum de la trucada (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "El bot de resum de trucades publica un missatge de visió general després de la trucada amb una llista de tots els participants i exposant les tasques",
    "Tasks" : "Tasques",
    "Notes" : "Notes",
    "Reports" : "Informes",
    "Decisions" : "Decisions",
    "Agenda" : "Agenda",
    "Call summary" : "Resum de la trucada",
    "Call summary - {title}" : "Resum de la trucada: {title}",
    "Talk to %s" : "Trucada a %s",
    "Talk conversation for event" : "Converses per a l'esdeveniment",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push està instal·lat, això millora el rendiment dels clients d'escriptori.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} no està instal·lat, això pot provocar problemes de rendiment quan s'utilitzen clients d'escriptori.",
    "Next meeting" : "Propera reunió",
    "Join conversations from remote Nextcloud servers" : "Uniu-vos a converses des de servidors remots de Nextcloud",
    "Your default media state has been saved" : "El vostre estat multimèdia predeterminat s'ha desat",
    "Set reminder for later today" : "Estableix un recordatori per a més tard avui",
    "Set reminder for tomorrow" : "Estableix un recordatori per a demà",
    "Set reminder for this weekend" : "Estableix un recordatori per a aquest cap de setmana",
    "Set reminder for next week" : "Estableix un recordatori per a la setmana següent",
    "Generate summary" : "Generar resum",
    "Open poll • You voted already" : "Enquesta oberta • Ja heu votat",
    "Open poll • Click to vote" : "Enquesta oberta • Feu clic per votar",
    "Poll • Ended" : "Enquesta • Finalitzada",
    "Talk recording from {time} ({conversation})" : "Enregistrament de conversa des de {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultats de l'enquesta • %n vot","Resultats de l'enquesta • %n vots"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Enquesta oberta • %n vot","Enquesta oberta • %n vots"],
    "Submit vote" : "Enviar vot",
    "Your privacy setting has been saved" : "Els vostres paràmetres de privadesa s'ha desat",
    "Your personal setting has been saved" : "La teva configuració personal s'ha desat",
    "Failed to save sounds setting" : "No s'han pogut desar els paràmetres dels sons",
    "Sounds setting saved" : "S'ha desat els paràmetres de sons",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Converses s'ha actualitzat, no pots iniciar ni unir-te a una trucada.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "S’ha unit a la conversa en una altra finestra o dispositiu. Actualment no és compatible amb Nextcloud Talk, de manera que aquesta sessió s'ha tancat.",
    "Nextcloud Talk was updated." : "Nextcloud Talk s'ha actualitzat.",
    "Nextcloud is in maintenance mode." : "Nextcloud està en mode de manteniment.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Converses Federació s'ha actualitzat."
},
"nplurals=2; plural=(n != 1);");
